@@ -7,6 +7,10 @@
 
 ----------------------------------------------------*/
 #include "default.h"
+
+typedef void *(* adm_fast_memcpy)(void *to, const void *from, size_t len);
+extern adm_fast_memcpy myMemcpy;
+#define memcpy myMemcpy
 /*          Video input iface        */
 typedef struct
 {
