@@ -41,19 +41,24 @@
 
 #include "nuppelvideo.h"
 //#include "avcodec.h"
-
+#include "../../avidemux/ADM_library/default.h"
+#include "../../avidemux/ADM_toolkit/ADM_cpuCap.h"
 #include "ffv1.h"
 #include "frequencies.h"
-#define _VERSION_ "0.2.1"
+#define _VERSION_ "0.2.3"
 
 
 /* Globals */
-
+extern "C"
+{
+extern uint8_t ADM_InitMemcpy(void);
+}
 static void parseRcFile( void );
 
 int recordaudio=1;
 int quiet;
 pthread_t pid_audio, pid_video, pid_buffer, pid_write;
+int CpuCaps::myCpuCaps=0;
 
 typedef  void *PTHR(void *);
 
@@ -161,6 +166,8 @@ int main(int argc, char** argv)
   int reclength= -1; // reclength in secs
  char c;
 
+	 CpuCaps::init	();
+	ADM_InitMemcpy();
 
   /////////////////////////////////////////////////////
   //  CHECKING AND INTERPRETING COMMAND LINE SWITCHES
