@@ -12,8 +12,13 @@ extern void *ADM_alloc(size_t size);
 extern void *ADM_realloc(void *in,size_t size);
 extern void ADM_dezalloc(void *ptr);
 extern char *ADM_strdup( const char *in);
-#define ADM_dealloc(x) ADM_dezalloc( (void *)x)
+typedef void *(* adm_fast_memcpy)(void *to, const void *from, size_t len);
+extern adm_fast_memcpy myMemcpy;
 
+#define ADM_memalign(x,y) ADM_alloc(y)
+
+#define ADM_dealloc(x) ADM_dezalloc( (void *)x)
+#define memcpy myMemcpy
 
 #define malloc #error
 #define realloc #error
