@@ -33,9 +33,16 @@
 //#include "ADM_gui/GUI_mp3.h"
 #include "ADM_audiofilter/audioeng_ffmp2.h"
 #include "ADM_audiofilter/audioeng_libtoolame.h"
+#ifdef USE_FAAC
+	#include "ADM_audiofilter/audioeng_faac.h"
+#endif
 #ifdef HAVE_LIBMP3LAME
 	#include "lame/lame.h"
 #endif
+#ifdef USE_VORBIS
+	#include "audioeng_vorbis.h"
+#endif
+
 #include "gui_action.hxx"
 /*
   	Ugly should get ride of it. Temporary fix.
@@ -48,22 +55,35 @@
 extern void UI_setAProcessToggleStatus( uint8_t status );
 extern uint8_t DIA_audioCodec( AUDIOENCODER *codec );
 extern int DIA_audioEncoder(int *pmode, int *pbitrate,const char *title);
+extern void UI_setAudioCodec( int i);
+uint32_t audioFilterGetNbEncoder(void);
+const char* audioFilterGetIndexedName(uint32_t i);
 
 typedef struct {
 	const char *name;
+	const char *menuName;
 	AUDIOENCODER codec;
 }CODECLIST;
 
 static CODECLIST myCodecList[]=
 {
 #ifdef HAVE_LIBMP3LAME
-		{"lame", AUDIOENC_MP3},
+		{"lame","Lame", AUDIOENC_MP3},
 #endif
-		{"mp2", AUDIOENC_MP2},
-		{"ac3", AUDIOENC_AC3},
-		{"toolame", AUDIOENC_2LAME},
-		{"none", AUDIOENC_NONE}
+#ifdef USE_FAAC
+		{"aac","FAAC", AUDIOENC_FAAC},
+#endif
+#ifdef USE_VORBIS
+		{"vorbis","Vorbis", AUDIOENC_VORBIS},
+#endif
+
+		{"mp2", "FFm MP2", AUDIOENC_MP2},
+		{"ac3", "FFm AC3",AUDIOENC_AC3},
+		{"toolame","Toolame", AUDIOENC_2LAME},
+		{"none", "Wav PCM",AUDIOENC_NONE}
 };
+extern int DIA_getLameSettings(int *pmode, int *pbitrate,ADM_LAME_PRESET *preset);
+extern void UI_PrintCurrentACodec( const char *s);
 
 #define MAX_AUDIO_FILTER 10
 static AVDMProcessAudioStream *filters[MAX_AUDIO_FILTER];
@@ -80,14 +100,31 @@ int 	   audioShift = 0;
 int	   audioDelay=0;
 
 FILMCONV audioFilmConv=FILMCONV_NONE;
-
+CHANNELCONV audioChannelConv=CHANNELCONV_NONE;
 
 // MP3 parameters
  int audioMP3mode = 0, audioMP3bitrate = 128;
-
+ ADM_LAME_PRESET audioMP3preset=ADM_LAME_PRESET_CBR;
 //
 static AUDIOENCODER  activeAudioEncoder=  AUDIOENC_NONE;
 
+void audioCodecChanged(int newcodec)
+{
+	ADM_assert(newcodec<sizeof(myCodecList) /sizeof(CODECLIST));
+	activeAudioEncoder=myCodecList[newcodec].codec;
+
+}
+
+uint32_t audioFilterGetNbEncoder(void)
+{
+	return sizeof(myCodecList) /sizeof(CODECLIST);
+}
+const char* audioFilterGetIndexedName(uint32_t i)
+{
+ 	ADM_assert(i<sizeof(myCodecList) /sizeof(CODECLIST));
+	return myCodecList[i].menuName;
+}
+
 void audioFilterNormalize(uint8_t onoff)
 {
 	audioNormalizeMode=onoff;
@@ -107,6 +144,23 @@ uint8_t audioFilterDelay(int32_t delay)
 	return 1;
 
 }
+uint8_t audioFilterMono2Stereo(uint8_t onoff)
+{
+	if(onoff)
+		audioChannelConv=CHANNELCONV_1to2;
+	else
+		audioChannelConv=CHANNELCONV_NONE;
+	return 1;
+}
+uint8_t audioFilterStereo2Mono(uint8_t onoff)
+{
+	if(onoff)
+		audioChannelConv=CHANNELCONV_2to1;
+	else
+		audioChannelConv=CHANNELCONV_NONE;
+	return 1;
+}
+
 uint8_t audioFilterFilm2Pal(uint8_t onoff)
 {
 	if(onoff) audioFilmConv=FILMCONV_FILM2PAL;
@@ -138,12 +192,12 @@ void audioFilter_SetBitrate( int i)
 }
 
 extern  int DIA_getAudioFilter(int *normalized, RESAMPLING *downsamplingmethod, int *tshifted,
-  			 int *shiftvalue, int *drc,int *freqvalue,FILMCONV *filmconv);
+  			 int *shiftvalue, int *drc,int *freqvalue,FILMCONV *filmconv,CHANNELCONV *channel);
 
 void audioFilter_configureFilters( void )
 {
 	 DIA_getAudioFilter(&audioNormalizeMode,&audioResampleMode,&audioShift,&audioDelay,&audioDRC,&audioFreq,
-	 		&audioFilmConv );
+	 		&audioFilmConv,&audioChannelConv );
 
 }
 
@@ -192,6 +246,7 @@ uint8_t audioCodecSetConf(char *name )
 
 	Read(audioMP3mode);
 	Read(audioMP3bitrate);
+	Read(audioMP3preset);
 	UI_setAProcessToggleStatus( newmode );
 	return 1;
 }
@@ -204,6 +259,7 @@ const char *audioCodecGetConf( void )
 	Add(audioProcessMode);
 	Add(audioMP3mode);
 	Add(audioMP3bitrate);
+	Add(audioMP3preset);
 
 	return conf;
 
@@ -232,6 +288,7 @@ uint8_t audioFilterSetByName( const char *name)
 	Read(audioShift);
 	Read(audioDelay);
 	Read(audioFreq);
+	Read(audioChannelConv);
 	return 1;
 }
 
@@ -248,20 +305,37 @@ const char *audioFilterGetName( void )
 	Add(audioShift);
 	Add(audioDelay);
 	Add(audioFreq);
+	Add(audioChannelConv);
 	return conf;
 
 }
+void audioPrintCurrentCodec(void)
+{
 
-
+	for(uint32_t i=0;i<sizeof(myCodecList)/sizeof(CODECLIST);i++)
+	{
+		if(activeAudioEncoder==myCodecList[i].codec)
+		{
+			UI_setAudioCodec(i);
+			return;
+		}
+	
+	}
+	ADM_assert(0);
+}
  void audioCodecSetcodec(AUDIOENCODER codec)
 {
 
 	activeAudioEncoder=codec;
+	audioPrintCurrentCodec();
+
 }
 
 void audioCodecSelect( void )
 {
 	DIA_audioCodec( &activeAudioEncoder );
+	audioPrintCurrentCodec();
+
 
 }
 /*
@@ -280,21 +354,34 @@ void audioCodecSelect( void )
 void audioCodecConfigure( void )
 {
 	int mode,bitrate;
+	ADM_LAME_PRESET preset;
 	bitrate= audioMP3bitrate;
+	preset=audioMP3preset;
 	mode=audioMP3mode;
+	
 	switch(activeAudioEncoder)
 	{
 		case AUDIOENC_NONE:
 								return;
+#ifdef USE_FAAC
+		case AUDIOENC_FAAC:
+						
+							DIA_audioEncoder(&audioMP3mode, &audioMP3bitrate,"AAC parameter");
+							return;
+						return;
+#endif	
+#ifdef USE_VORBIS
+		case AUDIOENC_VORBIS:
+						
+							DIA_audioEncoder(&audioMP3mode, &audioMP3bitrate,"VORBIS parameter");
+							return;
+						return;
+#endif		
 #ifdef HAVE_LIBMP3LAME								
 		case AUDIOENC_MP3:
-						
-							if (DIA_audioEncoder(&mode, &bitrate,"MP3 parameter"))
-								{
-									audioMP3mode=mode;
-									audioMP3bitrate=bitrate;										
-								}
-								return;
+						DIA_getLameSettings(&audioMP3mode, &audioMP3bitrate,&audioMP3preset);
+						return;
+						break;
 #endif
 
 		case AUDIOENC_MP2:
@@ -379,7 +466,7 @@ AVDMProcessAudioStream *buildInternalAudioFilter(AVDMGenericAudioStream *current
 						    audioDelay);
 		tshift = (AVDMProcessAudioStream *) ts;
 		lastFilter = tshift;
-		printf("\n Time shift activated with %d ms", audioShift);
+		printf("\n Time shift activated with %d %d ms", audioShift,audioDelay);
 		filters[filtercount++] = lastFilter;
 	    }
       }
@@ -466,7 +553,27 @@ AVDMProcessAudioStream *buildInternalAudioFilter(AVDMGenericAudioStream *current
 		break;
 	
 		
-      	}      		
+      	}   
+	switch(audioChannelConv)
+	{
+		case CHANNELCONV_NONE:break;
+		case CHANNELCONV_2to1:
+				AVDMProcessStereo2Mono *s2m;
+				s2m = new AVDMProcessStereo2Mono(lastFilter);
+				lastFilter = s2m;
+				filters[filtercount++] = lastFilter;	
+				break;
+		case CHANNELCONV_1to2:
+				AVDMProcessMono2Stereo *m2s;
+				m2s = new AVDMProcessMono2Stereo(lastFilter);
+				lastFilter = m2s;
+				filters[filtercount++] = lastFilter;	
+				break;
+		default:
+				ADM_assert(0);
+	
+	
+	}   		
 	
 	
 //_______________________________________________________
@@ -493,7 +600,7 @@ AVDMProcessAudioStream *lastFilter;
 						ts = new AVDMProcessAudio_TimeShift(lastFilter,    audioDelay);
 
 						lastFilter = ts;
-						printf("\n Time shift activated with %d ms", audioShift);
+						printf("\n Time shift activated with %d %d ms", audioShift,audioDelay);
 						filters[filtercount++] = lastFilter;
 
 	    				}
@@ -510,9 +617,27 @@ void audioSetResample(uint32_t fq)
 	audioResampleMode=RESAMPLING_CUSTOM;
 	audioFreq=fq;
 }
+/*
+	Build a fake filter chain without normalizer
+		to avoid to have to scan the file to get the max amplitude value
+
+*/
+AVDMProcessAudioStream *buildFakeAudioFilter(AVDMGenericAudioStream *currentaudiostream,
+				uint32_t starttime, uint32_t size)
+{
+	uint8_t stored_norm;
+	AVDMProcessAudioStream *out;
+		stored_norm=audioNormalizeMode;	// Temporarily disable normalizing
+		
+		audioNormalizeMode=0;
+		out=buildAudioFilter(currentaudiostream,starttime,size);
+		audioNormalizeMode=stored_norm;
+		return out;
+}
 /**
 		Build filter to save
 */
+
 AVDMProcessAudioStream *buildAudioFilter(AVDMGenericAudioStream *currentaudiostream,
 				uint32_t starttime, uint32_t size)
 {
@@ -550,7 +675,44 @@ uint8_t init;
  				filters[filtercount++] = lastFilter;
 			#endif
 			break;
-
+#ifdef USE_VORBIS
+		case AUDIOENC_VORBIS:
+		{
+				AVDMProcessAudio_Vorbis *vorbis;
+				vorbis = new AVDMProcessAudio_Vorbis(lastFilter);
+				if(vorbis->init(audioMP3bitrate))
+				{
+					lastFilter = vorbis;
+					filters[filtercount++] = lastFilter;
+				}
+ 				else
+				{
+					delete vorbis;
+					GUI_Alert("VORBIS initialization failed\n"
+							" NOT ACTIVATED");
+				}
+		}
+		break;
+#endif			
+#ifdef USE_FAAC
+		case AUDIOENC_FAAC:
+		{
+				AVDMProcessAudio_Faac *faac;
+				faac = new AVDMProcessAudio_Faac(lastFilter);
+				if(faac->init(audioMP3bitrate))
+				{
+					lastFilter = faac;
+					filters[filtercount++] = lastFilter;
+				}
+ 				else
+				{
+					delete faac;
+					GUI_Alert("FAAC initialization failed\n"
+							" NOT ACTIVATED");
+				}
+		}
+		break;
+#endif		
 #ifdef HAVE_LIBMP3LAME
 		case AUDIOENC_MP3:
         		{
@@ -560,7 +722,8 @@ uint8_t init;
 				printf("\n Init of lame with bitrate %d , mode %d ",
 							 audioMP3bitrate, audioMP3mode);
 			  	init = plame->initLame(0, 	(uint32_t) audioMP3mode,
-			      					(uint32_t) audioMP3bitrate);
+			      					(uint32_t) audioMP3bitrate,
+								audioMP3preset);
 
 			  	if (init)
 			    	{
@@ -676,21 +839,9 @@ AVDMProcessAudioStream *firstFilter = NULL;
 AVDMProcessAudioStream *lastFilter = NULL;
  
 	// Start from a clean state
+	printf("Building raw audio filter with start:%lu duration:%lu shift:%d\n",startTime,duration,shift);
 	deleteAudioFilter();	
-	
-	// No shift
-	if(shift<=0)
-	{	
-	
-		lastFilter=new AVDMProcessAudio_RawShift(currentaudiostream,0,startTime-shift);
-		filters[filtercount++] = lastFilter;
-		return lastFilter;	
-	}
-	// had to add a loop filter
-	if(startTime>shift)
-		lastFilter=new AVDMProcessAudio_RawShift(currentaudiostream,0,startTime-shift);
-	else
-		lastFilter=new AVDMProcessAudio_RawShift(currentaudiostream,shift,startTime);
+	lastFilter=new AVDMProcessAudio_RawShift(currentaudiostream,shift,startTime);
 	filters[filtercount++] = lastFilter;
 	return lastFilter;
 	
