@@ -16,6 +16,8 @@
  ***************************************************************************/
 
 #include "ADM_audiofilter/audioprocess.hxx"
+AVDMProcessAudioStream *buildFakeAudioFilter(AVDMGenericAudioStream *currentaudiostream,
+				uint32_t starttime, uint32_t size);
 
  AVDMProcessAudioStream *buildAudioFilter(AVDMGenericAudioStream *currentaudiostream,
 				uint32_t starttime, uint32_t size);
@@ -44,6 +46,8 @@ typedef enum AUDIOENCODER
 	AUDIOENC_MP2,
 	AUDIOENC_AC3,
 	AUDIOENC_2LAME,
+	AUDIOENC_FAAC,
+	AUDIOENC_VORBIS,
 	AUDIOENC_DUMMY
 }AUDIOENCODER;
 
@@ -63,6 +67,14 @@ typedef enum FILMCONV
 	FILMCONV_LAST
 }FILMCONV;
 
+typedef enum CHANNELCONV
+{
+	CHANNELCONV_NONE=0,
+	CHANNELCONV_2to1=1,
+	CHANNELCONV_1to2=2,
+	CHANNELCONV_last
+}CHANNELCONV;
+
 void audioCodecSetcodec(AUDIOENCODER codec);
 
 /*  for job/workspace stuff  */
@@ -75,7 +87,7 @@ uint8_t audioFilterSetByName( const char *name);
 const char *audioCodecGetConf( void );
 uint8_t audioCodecSetConf(char *conf );
 
-AVDMGenericAudioStream *mpt_getAudioStream(double *mypcm,uint8_t silent=0);
+AVDMGenericAudioStream *mpt_getAudioStream(void);
 
 void audioFilterNormalize(uint8_t onoff);
 void audioFilterDownsample(uint8_t onoff);
@@ -83,5 +95,8 @@ void audioFilterResample(uint32_t onoff);
 uint8_t audioFilterDelay(int32_t delay);
 uint8_t audioFilterFilm2Pal(uint8_t onoff);
 
+uint8_t audioFilterMono2Stereo(uint8_t onoff);
+uint8_t audioFilterStereo2Mono(uint8_t onoff);
+
 void audioFilter_SetBitrate( int i);
 
