@@ -21,7 +21,9 @@
     public:
     			decoderNull(uint32_t w,uint32_t h) :decoders(w,h) {}		
     			virtual ~decoderNull() {};	
-    			virtual uint8_t 	uncompress(uint8_t *in,uint8_t *out,uint32_t len)
-       						{ memcpy(out,in,len);return 1;}			
+    			virtual uint8_t 	uncompress(uint8_t *in,ADMImage *out,uint32_t len)
+       						{ memcpy(out->data,in,len);return 1;}
+			virtual uint8_t 	uncompress(uint8_t *in,ADMImage *out,uint32_t len,uint32_t *f)
+       						{ memcpy(out->data,in,len);return 1;}	
    }  ;
 
