@@ -80,6 +80,8 @@ uint8_t isMpeg4Compatible( uint32_t fourcc)
 
     uint8_t divx4=0;
 
+    		CHECK("FMP4");
+    		CHECK("fmp4");
     		CHECK("DIVX");
       		CHECK("divx");
 	       	CHECK("DX50");
@@ -185,7 +187,11 @@ decoders *getDecoderVopPacked(uint32_t fcc,uint32_t w, uint32_t h,uint32_t extra
 
 			  	     	return(decoders *)( new decoderFFhuff(w,h,extraLen,extraData));
 	   }
+  if(fourCC::check(fcc,(uint8_t *)"FFVH"))
+          {
 
+                                        return(decoders *)( new decoderFF_ffhuff(w,h,extraLen,extraData));
+           }
     if(fourCC::check(fcc,(uint8_t *)"SVQ3"))
           {
 
@@ -207,6 +213,11 @@ decoders *getDecoderVopPacked(uint32_t fcc,uint32_t w, uint32_t h,uint32_t extra
 
 			  	     	return(decoders *)( new decoderSnow(w,h));
 	   }
+           if(fourCC::check(fcc,(uint8_t *)"H264"))
+           {
+
+             return(decoders *)( new decoderFFH264(w,h));
+           }           
 #endif
 
 /*
