@@ -23,17 +23,21 @@
  class decoderFF : public decoders
 {
      protected:
+                                        uint8_t                 _refCopy;
 					AVCodecContext  	*_context;
 					AVFrame			_frame;
 					uint8_t 		*_internalBuffer;					
 					uint8_t			_allowNull; 	
 					uint32_t		_swapUV;	
 					uint32_t  		frameType( void );
-					
+					uint8_t                 clonePic(AVFrame *src,ADMImage *out);
 					uint32_t		_showMv;
+                                        uint32_t                _gmc;
      public:
+                                        
      					decoderFF(uint32_t w,uint32_t h);
          		virtual		~decoderFF();
+                        virtual         uint8_t dontcopy(void) { return _refCopy;}   
     			virtual 	uint8_t 	uncompress(uint8_t *in,ADMImage *out,
 						uint32_t len,uint32_t *flag=NULL) 		;
    		       virtual 		void 	setParam( void );
@@ -125,6 +129,15 @@ class decoderFFH263 : public decoderFF
      public:
      				          	decoderFFH263(uint32_t w,uint32_t h) ;
 	
+}   ;
+class decoderFFH264 : public decoderFF
+{
+  protected:
+                                
+                        
+  public:
+    decoderFFH264(uint32_t w,uint32_t h) ;
+        
 }   ;
 class decoderFFhuff : public decoderFF
 {
@@ -134,6 +147,15 @@ class decoderFFhuff : public decoderFF
      public:
      				         	decoderFFhuff(uint32_t w,uint32_t h,uint32_t l,uint8_t *d) ;
 
+}   ;
+class decoderFF_ffhuff : public decoderFF
+{
+           protected:
+                                
+                        
+     public:
+                                                decoderFF_ffhuff(uint32_t w,uint32_t h,uint32_t l,uint8_t *d) ;
+
 }   ;
 class decoderFFWMV2 : public decoderFF
 {
