@@ -46,6 +46,10 @@
 extern "C"
 {
 #include "libMpeg2Dec/video_out.h"
+#undef free
+#undef alloc
+#undef realloc
+	
 #include "libMpeg2Dec/mpeg2.h"
 #include "libMpeg2Dec/mpeg2_internal.h"
 #include <ADM_assert.h>
@@ -175,8 +179,13 @@ uint8_t 	decoderMpeg::uncompress(uint8_t *in,ADMImage *out,uint32_t len,uint32_t
 #if defined( REMOVE_PADDING)
 		while(*(in+len-1)==0) len--;
 #endif		
-		if(!len) return 1;
-		feedData(len,in);
+		if(!len)
+                {
+                        if(!dontcopy())
+                                return 1;
+                }
+                if(len)
+		      feedData(len,in);
 
 	const mpeg2_info_t  *info ;
 	uint8_t *t;
@@ -184,13 +193,36 @@ uint8_t 	decoderMpeg::uncompress(uint8_t *in,ADMImage *out,uint32_t len,uint32_t
 		t=(uint8_t *) MPEG2DEC->fbuf[0]->buf[0];
 		mpeg2_cleanup(MPEG2DEC);
 		info= mpeg2_info (MPEG2DEC);
-		
+		out->_noPicture=0;    // For mpeg1/2 we ALWAYS have a picture
 		if(out->quant && MPEG2DEC->decoder.quant_stride>=out->_qStride)
 		{
-			memcpy(out->quant,MPEG2DEC->decoder.quant,out->_qSize);
+                        
+
+                        if(dontcopy())
+                        {
+                             out->_qSize=((_w+15)>>4)*((_h+15)>>4);
+                             out->_qStride=(_w+15)>>4;
+                             out->quant=(uint8_t *)MPEG2DEC->decoder.quant;                             
+                        }
+                        else
+			     memcpy(out->quant,MPEG2DEC->decoder.quant,out->_qSize);
 		
 		}
-		memcpy(out->data,t,(_w*_h*3)>>1);
+                if(dontcopy())
+                {
+                        uint32_t plane=_w*_h;
+
+                        out->_planes[0]=t;
+                        out->_planes[1]=t+plane;
+                        out->_planes[2]=t+((plane*5)>>2);
+                        out->_planeStride[0]=_w;
+                        out->_planeStride[1]=_w>>1;
+                        out->_planeStride[2]=_w>>1;
+                }
+                else
+                {
+		      memcpy(out->data,t,(_w*_h*3)>>1);
+                }
 		
 		switch(MPEG2DEC->decoder.coding_type)
 			{
@@ -361,10 +393,17 @@ void yv12_close (vo_instance_t * _instance)
 static void yv12_setup_fbuf (vo_instance_t * _instance,			    uint8_t ** buf, void ** id)
 {
 	uint8_t *all;
-	uint32_t page,i,img;
+	uint32_t page,img;
+#ifdef ARCH_X86_64 
+	uint64_t i;
+	i=(uint64_t)id;
+
+#else
+	uint32_t i;
+	i=(uint32_t)id;
+#endif	
     
 	yv12_instance_t * instance = (yv12_instance_t *) _instance;
-	i=(uint32_t)id;
  	printf(" **********YV12 setup fbuf called : %lu x %lu (%lu)\n",instance->w,instance->h,i);
 
  	page=instance->w*instance->h;
