@@ -16,7 +16,7 @@
     public:
     					decoderUYVY(uint32_t w,uint32_t h):decoders(w,h) {};
     			virtual 	~decoderUYVY() {};       			
-    			virtual uint8_t uncompress(uint8_t *in,uint8_t *out,
+    			virtual uint8_t uncompress(uint8_t *in,ADMImage *out,
 						uint32_t len,uint32_t *flag=NULL);
    }  ;
  class decoderYUY2:decoders
@@ -26,7 +26,7 @@
     public:
     					decoderYUY2(uint32_t w,uint32_t h):decoders(w,h) {};
     			virtual 	~decoderYUY2() {};       			
-    			virtual uint8_t uncompress(uint8_t *in,uint8_t *out,
+    			virtual uint8_t uncompress(uint8_t *in,ADMImage *out,
 						uint32_t len,uint32_t *flag=NULL);
    }  ;
 
