@@ -21,32 +21,32 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 
-#include "ADM_assert.h" 
+
 
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 # include <math.h>
 
 #include "callbacks.h"
-#include "avi_vars.h"
+#include "ADM_library/default.h"//#include "avi_vars.h"
 #include "ADM_gui2/support.h"
 #include "ADM_toolkit/toolkit_gtk.h"
 #include "ADM_toolkit/toolkit_gtk_include.h"
 
 
-#include "ADM_library/default.h"
+
 #include "ADM_toolkit/toolkit.hxx"
 #include "ADM_encoder/ADM_vidEncode.hxx"
+#include "ADM_assert.h" 
 
-
-#include "ADM_codecs/ADM_ffmpegConfig.h"
+#include "mpeg2enc/ADM_mpeg2enc.h"
 #include "ADM_toolkit/toolkit.hxx"
 
 static GtkWidget	*create_dialog1 (void);
 static void 		updateMode( void );
 static int 		cb_mod(GtkObject * object, gpointer user_data);
-static void 		upload(GtkWidget *dialog, FFcodecSetting *conf);
-static void 		download(GtkWidget *dialog, FFcodecSetting *conf);
+static void 		upload(GtkWidget *dialog, Mpeg2encParam *conf);
+static void 		download(GtkWidget *dialog, Mpeg2encParam *conf);
 
 static GtkWidget 	*dialog=NULL;		      
 static uint32_t 	mQ,mB,mS;
@@ -54,7 +54,7 @@ static COMPRESSION_MODE mMode;
 
 
 uint8_t DIA_SVCDParam(char *title,COMPRESSION_MODE * mode, uint32_t * qz,
-		   	  uint32_t * br,uint32_t *fsize,FFcodecSetting *conf)
+		   	  uint32_t * br,uint32_t *fsize,Mpeg2encParam *conf)
 {	
 	int ret=0;
 	gint b;
@@ -119,33 +119,20 @@ uint8_t DIA_SVCDParam(char *title,COMPRESSION_MODE * mode, uint32_t * qz,
 				case 0:
 					*mode = COMPRESS_CBR;				      
 		      			value = (uint32_t) gtk_read_entry(WID(entryBitrate));
-		      			if (value < 9900)
-			  			value *= 1000;
-		      			if (value > 16 && value < 9900000)
-					{
-			    			*br = value;
-			    			ret = 1;
-		      			}
-					
+			    		*br = value * 1000;
 					break;
 				case 1:
 					*mode = COMPRESS_CQ;		      			
 					value = (uint32_t) gtk_spin_button_get_value_as_int(
 								GTK_SPIN_BUTTON(WID(spinbuttonQz)));
-		      			if (value >= 2 && value <= 32)
-					{
-			    			*qz = value;
-		      			}
+			    		*qz = value;
 		      			break;
 
 				case 2:
 		     			*mode = COMPRESS_2PASS;	
 					value = (uint32_t)
 						gtk_read_entry(WID(entryBitrate));
-        				if((value>0)&&(value<4000))
-          				{
-       						*fsize=value;	
-           				}
+       					*fsize=value;	
             				break;
 		  		default:
 		      			ADM_assert(0);
@@ -158,7 +145,7 @@ uint8_t DIA_SVCDParam(char *title,COMPRESSION_MODE * mode, uint32_t * qz,
 }	
 
 
-void upload(GtkWidget *dialog, FFcodecSetting *conf)
+void upload(GtkWidget *dialog, Mpeg2encParam *conf)
 {
  	gtk_option_menu_set_history (GTK_OPTION_MENU (WID(optionmenu2)),conf->user_matrix);
 // 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(WID(spinbutton1)),(float)conf->gop_size) ;
@@ -176,7 +163,7 @@ void upload(GtkWidget *dialog, FFcodecSetting *conf)
 	gtk_write_entry(WID(entryMax),(conf->maxBitrate*8)/1000);
 	
 }
-void download(GtkWidget *dialog, FFcodecSetting *conf)
+void download(GtkWidget *dialog, Mpeg2encParam *conf)
 {
 	SPIN_GET(spinbuttonGop,gop_size);
 	conf->user_matrix=getRangeInMenu(WID(optionmenu2));
