@@ -233,8 +233,9 @@ uint8_t  ADM_Composer::getUncompressedFrame (uint32_t frame, ADMImage * out,
     }
   //*************************
   // completly async frame
-  // rewind
+  // rewind ?
   //*************************
+    
   aprintf("async  frame, wanted : %lu last %lu (%lu - %lu seg)\n",relframe,_lastframe,seg,_lastseg);
   uint32_t rewind;
   uint32_t seekFlag=0;
@@ -242,6 +243,7 @@ uint8_t  ADM_Composer::getUncompressedFrame (uint32_t frame, ADMImage * out,
   _videos[ref]._aviheader->getFlags (relframe, &seekFlag);
   
   flags = 0;
+  uint32_t need_rewind=1;
   rewind = relframe;
   ADM_assert(rewind); // the first frame should be a keyframe !
   while (!(flags & AVI_KEY_FRAME))
@@ -249,23 +251,51 @@ uint8_t  ADM_Composer::getUncompressedFrame (uint32_t frame, ADMImage * out,
   	rewind--;
   	_videos[ref]._aviheader->getFlags (rewind, &flags);	
    }
+   // Optimize for resample FPS*************************
+   // If we are in the same segment, look if it is better to decode
+    // From where we are or to seek the previous intra
+   if ((seg == _lastseg))
+   {
+     if(rewind<_lastframe && relframe>_lastframe) // we have a better position to go from
+     { 
+       for (uint32_t i = _lastframe+1; i <relframe; i++)
+       {
+
+         _videos[ref]._aviheader->getFlags (i, &flags);
+      // Skip B frames, there can be a lot of them
+         if((flags&AVI_B_FRAME)) continue;
+     
+         if(!decodeCache(i,ref, result))                  
+         {
+           printf("Editor: Cannot read ip frame %lu\n",relframe);
+           return 0;
+         }
+         result=cache->getFreeImage();      
+       }
+       need_rewind=0;
+     }
+   }
+   // Optimize for resample FPS*************************
+   // 
   // now forward
   // IP seen is the last P (or I) before the frame we seek
-  for (uint32_t i = rewind; i <relframe; i++)
-    {
+   if(need_rewind)
+   {
+        for (uint32_t i = rewind; i <relframe; i++)
+        {
 
-      _videos[ref]._aviheader->getFlags (i, &flags);
-      // Skip B frames, there can be a lot of them
-      if((flags&AVI_B_FRAME)) continue;
+                _videos[ref]._aviheader->getFlags (i, &flags);
+                // Skip B frames, there can be a lot of them
+                if((flags&AVI_B_FRAME)) continue;
      
-       if(!decodeCache(i,ref, result))			
-	{
-		printf("Editor: Cannot read ip frame %lu\n",relframe);
-		return 0;
-	}
-	result=cache->getFreeImage();      
-      }
-      
+                if(!decodeCache(i,ref, result))			
+	        {
+		      printf("Editor: Cannot read ip frame %lu\n",relframe);
+		      return 0;
+	        }
+	        result=cache->getFreeImage();      
+        }
+   }
       // Time to decode our frame
       // if it is not a B, just decode it
       // it it is a B, the usual stuff
@@ -336,6 +366,10 @@ uint32_t len;
 uint32_t flags,sumit;
 float	 sum;
 EditorCache *cache=_videos[seg]._videoCache;	
+ADMImage *tmpImage=NULL;
+uint8_t refOnly=0;
+uint32_t left,ww;
+
 	 if (!_videos[seg]._aviheader->getFrameNoAlloc (frame,
 						     compBuffer,
 						     &len, &flags))
@@ -343,19 +377,58 @@ EditorCache *cache=_videos[seg]._videoCache;
 	  printf ("\nEditor: last decoding failed.%ld)\n",   frame );
 	  return 0;
 	}
-	ADM_assert(_imageBuffer);
+        ADM_assert(_imageBuffer);
+
+        // if len is 0 then take the previous image                 
+        //
+
+        refOnly=_videos[seg].decoder->dontcopy(); // can we skip one memcpy ?
+
+        if(!len & refOnly & !frame)      // Size is null = no image and we only got a pointer
+                                // copy the previous one
+        {                
+                // First image
+                
+                uint32_t page=_imageBuffer->_width*_imageBuffer->_height;
+                        memset(YPLANE(image),0,page);
+                        memset(UPLANE(image),128,page>>2);
+                        memset(VPLANE(image),128,page>>2);
+                        if(!frame)
+                                image->flags=AVI_KEY_FRAME;
+                        else            
+                                image->flags=AVI_P_FRAME;
+                        image->_Qp=2;
+                        image->_qStride=0;
+                        return 1;        
+        }
+
+        if(refOnly)
+        {       // This is only an empty Shell
+                tmpImage=new ADMImage(_imageBuffer->_width,_imageBuffer->_height,1);
+                ww=_imageBuffer->_width & 0xfffff0;
+                left=_imageBuffer->_width & 0xf;
+
+        }
+        else
+        {
+                tmpImage=_imageBuffer;
+                ww=_imageBuffer->_width;
+                left=0;
+       }
+	
 	// Do pp, and use imageBuffer as intermediate buffer
-	if (!_videos[seg].decoder->uncompress (compBuffer, _imageBuffer, len, &flags))
+	if (!_videos[seg].decoder->uncompress (compBuffer, tmpImage, len, &flags))
 	    {
 	      printf ("\nEditor: Last Decoding2 failed for frame %lu\n",frame);
 	      return 0;
 	    }
 	// Quant ?
-	if(!_imageBuffer->quant || !_imageBuffer->_qStride)
-	{
-		_imageBuffer->_Qp=2;
-		image->duplicate(_imageBuffer);
+	if(!tmpImage->quant || !tmpImage->_qStride)
+	{      
+		image->_Qp=2;
+		image->duplicate(tmpImage);
 		cache->updateFrameNum(image,frame);
+                if(refOnly) delete tmpImage;
 		aprintf("EdCache: No quant avail\n");
 		return 1;
 	}
@@ -363,33 +436,41 @@ EditorCache *cache=_videos[seg]._videoCache;
 	// 1 compute average quant
 	int qz;
 	sumit=0;
-	for(uint32_t z=0;z<_imageBuffer->_qSize;z++)
+        // Dupe infos
+        image->copyInfo(tmpImage);
+        //image->copyQuantInfo(tmpImage);
+
+        // Do postprocessing if any
+	for(uint32_t z=0;z<tmpImage->_qSize;z++)
 	{
-            qz=(int)_imageBuffer->quant[z];
+            qz=(int)tmpImage->quant[z];
 			sumit+=qz;
 	}
-	sumit+=(_imageBuffer->_qSize-1);
+	sumit+=(tmpImage->_qSize-1);
 //	sumit*=2;
 	sum=(float)sumit;
-	sum/=_imageBuffer->_qSize;
+	sum/=tmpImage->_qSize;
 	if(sum>31) sum=31;
 	if(sum<1) sum=1;
-		
-	_imageBuffer->_Qp=(uint32_t)floor(sum);
+	
+        // update average Q	
+	tmpImage->_Qp=image->_Qp=(uint32_t)floor(sum);
 	
 	// Pp deactivated ?
 	if(!_pp.postProcType || !_pp.postProcStrength)
 	{
-		image->duplicate(_imageBuffer);
+                // nothing to do
+		image->duplicate(tmpImage);
 		cache->updateFrameNum(image,frame);
+                if(refOnly) delete tmpImage;
 		aprintf("EdCache: Postproc disabled\n");
 		return 1;	
 	}
 	
 	int type;	
 	#warning FIXME should be FF_I_TYPE/B/P
-	if(_imageBuffer->flags & AVI_KEY_FRAME) type=1;
-		else if(_imageBuffer->flags & AVI_B_FRAME) type=3;
+	if(tmpImage->flags & AVI_KEY_FRAME) type=1;
+		else if(tmpImage->flags & AVI_B_FRAME) type=3;
 			else type=2;
 	
 	// we do postproc !
@@ -400,39 +481,102 @@ EditorCache *cache=_videos[seg]._videoCache;
 	aviInfo _info;
 		
 		getVideoInfo(&_info);
-		iBuff[0]= YPLANE((_imageBuffer));
-		if(1)
-		{
-			iBuff[1]= UPLANE((_imageBuffer));
- 			iBuff[2]= VPLANE((_imageBuffer));
-		}
-		else
-		{
-			iBuff[2]= UPLANE((_imageBuffer));
- 			iBuff[1]= VPLANE((_imageBuffer));
-		}
-			oBuff[0]= YPLANE(image);
-			oBuff[1]= UPLANE(image);
- 			oBuff[2]= VPLANE(image);
-        			
-			strideTab[0]=strideTab2[0]=_info.width;
-			strideTab[1]=strideTab2[1]=_info.width>>1;
-			strideTab[2]=strideTab2[2]=_info.width>>1;
-            			
+                if(refOnly)
+                {
+                        iBuff[0]= tmpImage->_planes[0];
+                        iBuff[1]= tmpImage->_planes[1];
+                        iBuff[2]= tmpImage->_planes[2];
+        
+                        strideTab2[0]=_info.width;
+                        strideTab2[1]=_info.width>>1;
+                        strideTab2[2]=_info.width>>1;
+
+                        strideTab[0]=tmpImage->_planeStride[0];
+                        strideTab[1]=tmpImage->_planeStride[1];
+                        strideTab[2]=tmpImage->_planeStride[2];
+                        
+                }
+                else
+                {
+		        iBuff[0]= YPLANE((tmpImage));
+			iBuff[1]= UPLANE((tmpImage));
+ 			iBuff[2]= VPLANE((tmpImage));
+		
+                	
+                                                                
+                        strideTab[0]=strideTab2[0]=_info.width;
+                        strideTab[1]=strideTab2[1]=_info.width>>1;
+                        strideTab[2]=strideTab2[2]=_info.width>>1;
+                }
+        	        oBuff[0]= YPLANE(image);
+                        oBuff[1]= UPLANE(image);
+                        oBuff[2]= VPLANE(image);		
+
 		 pp_postprocess(
 		 		iBuff,
 		 		strideTab,
 		 		oBuff,
 		 		strideTab2,
-		 		_info.width,
+		 		ww,
 		        	_info.height,
-		          	(int8_t *)(_imageBuffer->quant),
-		          	_imageBuffer->_qStride,
+		          	(int8_t *)(tmpImage->quant),
+		          	tmpImage->_qStride,
 		         	_pp.ppMode,
 		          	_pp.ppContext,
 		          	type);			// img type
-				// update some infos
-		image->copyInfo(_imageBuffer);
+                /* 
+                        If there is a chroma block that needs padding
+                        (width not multiple of 16) while postprocessing,
+                        we process up to the nearest 16 multiple and
+                        just copy luma & chroma info that was left over
+                */
+                if(refOnly && left)
+                {
+                        uint8_t *src,*dst;
+                        uint32_t stridein,strideout,right;
+                        right=_info.width-left;
+                        // Luma
+                        dst=YPLANE(image)+right;
+                        src=tmpImage->_planes[0]+right;
+                        stridein=tmpImage->_planeStride[0];
+                        strideout=_info.width;
+                        for(uint32_t y=_info.height;y>0;y--)
+                        {
+                                memcpy(dst,src,left);
+                                dst+=strideout;
+                                src+=stridein;
+                        }
+                        // Chroma
+                        left>>=1;
+                        right>>=1;
+                        //
+                        dst=UPLANE(image)+right;
+                        src=tmpImage->_planes[1]+right;
+                        stridein=tmpImage->_planeStride[1];
+                        strideout=_info.width>>1;
+                        for(uint32_t y=_info.height>>1;y>0;y--)
+                        {
+                                memcpy(dst,src,left);
+                                dst+=strideout;
+                                src+=stridein;
+                        }
+                        //
+                        dst=VPLANE(image)+right;
+                        src=tmpImage->_planes[2]+right;
+                        stridein=tmpImage->_planeStride[2];
+                        strideout=_info.width>>1;
+                        for(uint32_t y=_info.height>>1;y>0;y--)
+                        {
+                                memcpy(dst,src,left);
+                                dst+=strideout;
+                                src+=stridein;
+                        }
+                        
+
+                }
+
+                // update some infos
+                if(refOnly) delete tmpImage;
 		cache->updateFrameNum(image,frame);
 		aprintf("EdCache: Postproc done\n");
 		return 1;	
