@@ -68,7 +68,7 @@ extern void oplug_mpeg_svcd(char *name);
 extern void oplug_mpeg_dvd(char *name);
 extern void oplug_mpeg_svcdConf( void );
 extern void oplug_mpeg_dvdConf( void );
-extern void mpeg_passthrough(  char *name );
+//extern void mpeg_passthrough(  char *name );
 
 extern void UI_PrintCurrentVCodec(const char *str);
 extern void oplug_mpegff_conf(void);
@@ -424,7 +424,7 @@ extern  uint8_t DIA_DVDffParam(COMPRESSION_MODE * mode, uint32_t * qz,
 		0, //int kfreduction;
 		0, //int kfthreshold;
 	
-		24,//int container_frame_overhead;
+		0, //24,//int container_frame_overhead;
 		150,//int bquant_ratio;
 		100,//int bquant_offset;    
 		1, //vhqmode		    
@@ -448,7 +448,24 @@ static MJPEGConfig mjpegConfig={90,0};
 extern uint8_t DIA_mjpegCodecSetting( int *qual, int *swap );
 #endif
 
+///////////////////////////////////////////:
+#ifdef USE_X264
 
+#include "ADM_encoder/adm_encx264.h"
+static X264Config  x264Config
+={
+  {COMPRESS_CQ,4,1500000,700},
+  {
+  2,    //uint32_t qmin;
+  51,   //uint32_t qmax;
+  1,    //uint32_t cabac;
+  250,  //uint32_t maxKf;
+  5,    //uint32_t minKf;
+  2,    //uint32_t nbBframe;  
+  } 
+};
+extern uint8_t DIA_x264(X264Config *config);
+#endif
 
 ///////////////////////////////////////////
 #ifdef USE_DIVX
@@ -520,6 +537,11 @@ void videoCodecSetConf(  char *name,uint32_t extraLen, uint8_t *extraData)
 		      		break;
 				
 #endif
+#ifdef USE_X264
+                case CodecX264:
+                                MAKECONF(x264Config);
+                                break;
+#endif
 #ifdef USE_XX_XVID
       	 	case CodecXvid :
 
@@ -559,6 +581,7 @@ void videoCodecSetConf(  char *name,uint32_t extraLen, uint8_t *extraData)
 					case  CodecH263:
 					case  CodecH263P:
 					case  CodecHuff:
+                                        case  CodecFFhuff:
 					case  CodecFFV1:
 					case  CodecSnow:
 											MAKECONF(ffmpegConfig);
@@ -599,6 +622,12 @@ const char  *videoCodecGetConf( uint32_t *optSize, uint8_t **data)
 
 	switch( current_codec)
 	{
+#ifdef USE_X264
+                                case CodecX264:
+                                        *data=(uint8_t *)&x264Config;
+                                        *optSize=sizeof(x264Config);
+                                         break;
+#endif          
 #ifdef USE_XX_XVID
       	 			case CodecXvid :
 						*data=(uint8_t *)&xvidConfig;
@@ -629,6 +658,7 @@ const char  *videoCodecGetConf( uint32_t *optSize, uint8_t **data)
 					case  CodecH263:
 					case  CodecH263P:
 					case  CodecHuff:
+                                        case  CodecFFhuff:
 					case  CodecFFV1:
 					case CodecSnow:
 
@@ -688,11 +718,18 @@ uint8_t raw;
 		case ADM_PS:
 				raw=0;
 				break;
+                case ADM_TS:
+                                raw=2;
+                                break;
 		default:
 				GUI_Alert("Please select mpeg output");
 				return;
 	}
-	
+	if(current_codec!=CodecDVD && raw==2)
+        {
+                GUI_Alert("Please select DVD to export as mpeg TS");
+                return;
+        }
 	switch(current_codec)
 	{
 		case CodecVCD:
@@ -708,11 +745,13 @@ uint8_t raw;
 					oplug_mpeg_svcd_ps(name);
 				break;
 		case CodecDVD:
-				if(raw)
-					oplug_mpeg_dvd(name);
-				else
-					oplug_mpeg_dvd_ps(name);
-				
+                                switch(raw)
+                                {
+                                        case 2:oplug_mpeg_ts(name);break;
+                                        case 1:oplug_mpeg_dvd(name);break;
+                                        case 0:oplug_mpeg_dvd_ps(name);break;
+                                        default : ADM_assert(0);
+                                }
 				break;
 		default:ADM_assert(0);
 	}
@@ -883,9 +922,13 @@ static const codecEnumByName mycodec[]=
 	{CodecXDVD	,"DVD (lavc)","XDVD"},
 	{CodecFF	,"Lav Mpeg4","FFmpeg4"},
 	{CodecH263	,"H263","H263"},
+        {CodecFFhuff    ,"FF Huffyuv","FFHUFF"},
 	{CodecH263P	,"H263+","H263+"},
 	{CodecHuff	,"Huffyuv","Huffyuv"},
 	{CodecFFV1	,"FFV1","FFV1"},
+#ifdef USE_X264
+        {CodecX264,     "X264","X264"},
+#endif                
 	{CodecSnow	,"Snow","Snow"}
 };
 uint32_t encoderGetNbEncoder(void)
@@ -1087,6 +1130,7 @@ void videoCodecConfigureUI( void )
 #endif
 #ifdef USE_FFMPEG	
 		case CodecHuff:
+                case CodecFFhuff:
 				break;
 		case CodecFFV1:
 				break;
@@ -1101,8 +1145,12 @@ void videoCodecConfigureUI( void )
 					  }
 				}
 					break;
-
-		case  CodecH263P:
+#ifdef USE_X264
+                case CodecX264:
+                                        DIA_x264(&x264Config);
+                                        break;
+#endif
+		case  CodecH263P:                  
 					printf("\n H263P\n");					
 		case  CodecH263:  
 					printf("\n H263\n");					
@@ -1167,6 +1215,13 @@ void setVideoEncoderSettings(COMPRESSION_MODE mode, uint32_t  param, uint32_t ex
 						specSize=sizeof(xvid4Config.specific);
 		      		break;
 #endif
+#ifdef USE_X264
+                                case CodecX264:
+                                                generic=&x264Config.generic;
+                                                specific=&x264Config.specific;
+                                                specSize=sizeof(x264Config.specific);
+                                        break;
+#endif
 #ifdef  USE_FFMPEG
 					case CodecMjpeg :
 
@@ -1185,6 +1240,7 @@ void setVideoEncoderSettings(COMPRESSION_MODE mode, uint32_t  param, uint32_t ex
 					case  CodecH263:
 					case  CodecH263P:
 					case  CodecHuff:
+                                        case  CodecFFhuff:
 					case  CodecFFV1:
 					case  CodecSnow:
 
@@ -1201,6 +1257,11 @@ void setVideoEncoderSettings(COMPRESSION_MODE mode, uint32_t  param, uint32_t ex
 									specific=&ffmpegMpeg1Config.specific;
 									specSize=sizeof(ffmpegMpeg1Config.specific);
 									break;
+                                        case CodecXDVD:
+                                                                        generic=&ffmpegMpeg2ConfigDVD.generic;
+                                                                        specific=&ffmpegMpeg2ConfigDVD.specific;
+                                                                        specSize=sizeof(ffmpegMpeg2ConfigDVD.specific);
+                                                                        break;
 #endif
 					default:
 								ADM_assert(0);
@@ -1261,8 +1322,15 @@ Encoder *e=NULL;
 				  		e=new   EncoderFFMPEG(FF_MPEG4,&ffmpegConfig);
 				    	break;			
 #endif		
-
+#ifdef USE_X264
+                case CodecX264:
+                                        e=new EncoderX264(&x264Config);
+                                        break;
+#endif
 #ifdef USE_FFMPEG
+                case   CodecFFhuff:             
+                                        e=new   EncoderFFMPEGFFHuff(&ffmpegConfig);
+                                        break;
 		case   CodecHuff:
 					e=new   EncoderFFMPEGHuff(&ffmpegConfig);
 				    	break;
