@@ -71,6 +71,27 @@ public:
 			  uint32_t * flags);
   virtual uint8_t hasExtraHeaderData( uint32_t *l,uint8_t **data);
 
+};
+class EncoderFFMPEGFFHuff:public EncoderFFMPEG
+{
+
+protected:
+
+
+public:
+        EncoderFFMPEGFFHuff (FFMPEGConfig *config);
+        ~EncoderFFMPEGFFHuff() { stop();}; // can be called twice if needed ..
+  virtual uint8_t isDualPass (void) { return 0;};
+  virtual uint8_t configure (AVDMGenericVideoStream * instream);
+  virtual uint8_t setLogFile (const char *p, uint32_t fr)  { UNUSED_ARG(p); UNUSED_ARG(fr); return 1;};
+  virtual uint8_t startPass2 (void) { return 1;};
+  virtual uint8_t startPass1 (void) { return 1;};
+  virtual const char *getDisplayName(void ) {return "LavCodec HUFFYUV";}
+  virtual const char *getFCCHandler(void ) {return "HFYU";}
+  virtual uint8_t encode (uint32_t frame, uint32_t * len, uint8_t * out,
+                          uint32_t * flags);
+  virtual uint8_t hasExtraHeaderData( uint32_t *l,uint8_t **data);
+
 };
 
 class EncoderFFMPEGFFV1:public EncoderFFMPEG
