@@ -118,6 +118,10 @@ typedef enum
 	CodecXSVCD,
 	CodecXDVD,
 	CodecXvid4,
+        CodecFFhuff,
+#ifdef USE_X264
+        CodecX264,
+#endif        
 	CodecDummy	
 }SelectCodecType;
 
