@@ -49,6 +49,7 @@ void registerVideoFilters( void )
 printf("\n Registering Filters\n");
 printf(  "*********************\n");
 
+	
 	registerFilter("---- Image size/border alteration----",VF_INVALID,2,NULL,NULL);
 	REGISTERX("crop","Crop",VF_CROP,1,crop_create,crop_script);
 	REGISTERX("mpresize","Mplayer Resize",VF_MPLAYERRESIZE,1,mpresize_create,mpresize_script);
@@ -57,6 +58,10 @@ printf(  "*********************\n");
   	REGISTERX("addblack","Add black border",VF_ADDBORDER,1,addBorder_create,addBorder_script);
   	REGISTERX("vflip","Flip Vertical",VF_FLIP,1,flipv_create,flipv_script);
 	REGISTERX("rotate","Rotate",VF_ROTATE,1,rotate_create,rotate_script);
+        //REGISTERX("chfps","Change FPS",VF_CHFPS,1,chfps_create,chfps_script);
+        REGISTERX("resamplefps","Resample FPS",VF_RESAMPLE_FPS,1,resamplefps_create,resamplefps_script);                
+        REGISTERX("msharpen","MSharpen by Donald Graft",VF_MSHARPEN,1,msharpen_create,msharpen_script);
+        REGISTERX("asharp","ASharp by MarcFD",VF_ASHARP,1,asharp_create,asharp_script);
 	REGISTERX("whirl","Whirl",VF_WHIRL,1,whirl_create,whirl_script);
 	registerFilter("----------- Interlacing -------------",VF_INVALID,2,NULL,NULL);
 	// Buggy : Removed REGISTER("IVTC",VF_IVTC,1,ivtc_create);
@@ -66,8 +71,11 @@ printf(  "*********************\n");
 	
 	REGISTER("palsmart","PAL-SMART",VF_TELECIDE,1,telecide_create);
 	REGISTERX("deinterlace","Deinterlace",VF_DEINTERLACE,1,deinterlace_create,deinterlace_script);
-	REGISTERX("lavdeint","Lavcodec Deinterlacer",VF_LAVDEINT,1,lavdeint_create,lavdeint_script);
-	REGISTERX("palfieldshift","Pal Field shift",VF_PALSHIFT,1,addPALShift_create,addPALShift_script);
+//	REGISTERX("lavdeint","Lavcodec Deinterlacer",VF_LAVDEINT,1,lavdeint_create,lavdeint_script);
+        
+        REGISTERX("lavcppdeint","Lavcodec PP Deinterlacer",VF_LAVPP_DEINT,1,lavppdeint_create,lavppdeint_script);
+        
+        REGISTERX("palfieldshift","Pal Field shift",VF_PALSHIFT,1,addPALShift_create,addPALShift_script);
 	
 	REGISTERX("drop","Drop",VF_DROPOUT,1,dropout_create,dropout_script);
 	REGISTERX("swapfields","SwapFields",VF_SWAPFIELDS,1,swapfield_create,swapfield_script);
@@ -75,14 +83,16 @@ printf(  "*********************\n");
 
 	REGISTERX("keepevenfield","Keep even fields",VF_KEEPEVEN,1,keepeven_create,keepeven_script);
 	REGISTERX("keepoddfield","Keep odd fields",VF_KEEPODD,1,keepodd_create,keepodd_script);
-	REGISTERX("separatefields","Separate Fields",VF_SEPARATEFIELDS,1,
-							separatefield_create,separatefield_script);
-	REGISTERX("stackfield","Stack Fields",VF_STACKFIELD,1,stackfield_create,stackfield_script);
+	REGISTERX("separatefields","Separate Fields",VF_SEPARATEFIELDS,1, separatefield_create,separatefield_script);
 	REGISTERX("mergefield","Merge Fields",VF_MERGEFIELDS,1,mergefield_create,mergefield_script);
+
+	REGISTERX("stackfield","Stack Fields",VF_STACKFIELD,1,stackfield_create,stackfield_script);
+        REGISTERX("unstackfield","UnStack Fields",VF_UNSTACK_FIELD,1,unstackfield_create,unstackfield_script);
+	
 	REGISTERX("pulldown","PullDown",VF_PULLDOWN,1,pulldown_create,pulldown_script);
 	
 	REGISTERX("kerneldeint","D. Graft Kernel deint",VF_KRNDEINT,1,kerneldeint_create,kerneldeint_script);
-	
+	REGISTERX("dgbob","DGBob",VF_DGBOB,1,dgbob_create,dgbob_script);
 
 	REGISTER("","Partial",VF_PARTIAL,0,partial_create);
 	registerFilter("-------- Convolution Kernel ---------",VF_INVALID,2,NULL,NULL);
@@ -104,6 +114,8 @@ printf(  "*********************\n");
 	REGISTERX("lumaonly","Luma only",VF_LUMA,1,luma_create,luma_script);
 	REGISTERX("chromauonly","Chroma U only",VF_CHROMAU,1,chromaU_create,chromaU_script);
 	REGISTERX("chromavonly","Chroma V only",VF_CHROMAV,1,chromaV_create,chromaV_script);
+        REGISTERX("hue","Mplayer Hue",VF_HUE,1,hue_create,hue_script);
+        REGISTERX("eq2","Mplayer Eq2",VF_EQ2,1,Eq2_create,Eq2_script);
 		
 	registerFilter("-------------- Smoother -------------",VF_INVALID,2,NULL,NULL);
 	//   registerFilter("Temporal smoother",tempsmooth_create);	
@@ -111,7 +123,7 @@ printf(  "*********************\n");
 	REGISTERX("denoise","Denoise",VF_DENOISE,1,denoise_create,denoise_script);
 	REGISTERX("fluxsmooth","FluxSmooth",VF_FLUXSMOOTH,1,fluxsmooth_create,fluxsmooth_script);
 	
-#ifdef USE_MMX
+#if defined( ARCH_X86)  || defined(ARCH_X86_64)
     	REGISTERX("temporalcleaner","Temporal Cleaner",VF_VLADSMOOTH,1,vladsmooth_create,vladsmooth_script);
 #endif
 
@@ -125,6 +137,8 @@ printf(  "*********************\n");
 	registerFilter("----------------- Misc --------------",VF_INVALID,2,NULL,NULL);
 	REGISTERX("subtitle","Subtitler",VF_SUBTILE,1,subtitle_create,subtitle_script);
 #endif
+        REGISTERX("vobsub","VobSub",VF_VOBSUB,1,vobsub_create,vobsub_script);
+
 //	REGISTER("","Remove Salt",VF_SALT,0,salt_create);
  printf("\n");
 }		
