@@ -73,6 +73,16 @@
 		VF_STACKFIELD,
 		VF_WHIRL,
 		VF_EQUALIZER,
+                VF_VOBSUB,
+                VF_CHFPS,
+                VF_RESAMPLE_FPS,
+                VF_LAVPP_DEINT,
+                VF_UNSTACK_FIELD,
+                VF_HUE,
+                VF_EQ2,
+                VF_DGBOB,
+                VF_MSHARPEN,
+                VF_ASHARP,
 		VF_DUMMY
  	 }VF_FILTERS;
  	
