@@ -54,8 +54,9 @@ CALLBACK(to_other1 				,ACT_Pipe2Other);
  CALLBACK( go_to_marker_a1  			,ACT_GotoMarkA);
  CALLBACK( go_to_marker_b1 			,ACT_GotoMarkB);
 
- CALLBACK( search_previous_black_frame1  			,ACT_PrevBlackFrame);
- CALLBACK( search_next_black_frame1 			,ACT_NextBlackFrame);
+ CALLBACK( search_previous_black_frame1  	,ACT_PrevBlackFrame);
+ CALLBACK( search_next_black_frame1		,ACT_NextBlackFrame);
+ CALLBACK( scan_for_black_frames1               ,ACT_AllBlackFrames);
 
  
 CALLBACK(reset_edits1                		,ACT_ResetSegments);
@@ -91,8 +92,8 @@ CALLBACK(	check_frames			,ACT_VideoCheck);
  CALLBACK(quit1		   			,ACT_Exit);
  
  CALLBACK(requantize_mpeg1		   	,ACT_Requant);
-  CALLBACK(run_script1		   	,ACT_RunScript);
-
+ CALLBACK(run_script1		   	        ,ACT_RunScript);
+ CALLBACK( ocr_vobsub_2_srt                     ,ACT_Ocr);
 
    
    
