@@ -1,4 +1,7 @@
+#ifndef ADM_GUI
+#define ADM_GUI
 
+#include "ADM_editor/ADM_outputfmt.h"
 
 void UI_updateFrameCount(uint32_t curFrame);
 void UI_setFrameCount(uint32_t curFrame,uint32_t total);
@@ -8,7 +11,7 @@ void UI_setTimeCount(uint32_t curFrame,uint32_t total, uint32_t fps);
 
 double 	UI_readScale( void );
 void 	UI_setScale( double  val );
-void 	UI_setFrameType( uint32_t frametype);
+void 	UI_setFrameType( uint32_t frametype,uint32_t qp);
 void 	UI_setMarkers(uint32_t a, uint32_t b );
 void 	UI_setTitle(char *name);
 
@@ -25,3 +28,12 @@ void UI_deiconify( void );
 uint32_t UI_readCurFrame( void );
 void UI_JumpDone(void);
 
+int 	UI_getCurrentACodec(void);
+int 	UI_getCurrentVCodec(void);
+void UI_setAudioCodec( int i);
+void UI_setVideoCodec( int i);
+
+ADM_OUT_FORMAT 	UI_GetCurrentFormat( void );
+uint8_t 	UI_SetCurrentFormat( ADM_OUT_FORMAT fmt );
+#endif
+// EOF
