@@ -37,7 +37,7 @@
 #define MODULE_NAME MODULE_ODML
 #include "ADM_toolkit/ADM_debug.h"
 
-#define OPENDML_VERBOSE
+//#define OPENDML_VERBOSE
 
 
 typedef struct OPENDML_INDEX
@@ -67,7 +67,11 @@ typedef struct OPENML_SECONDARY_INDEX
 	uint32_t	chunkId;
 	uint64_t	base;
 	uint32_t	reserver;
-};
+}
+#ifdef CYG_MANGLING
+__attribute__ ((packed))
+#endif
+;
 
 /*
 	Try to index if it is/was an openDML file
@@ -115,6 +119,12 @@ uint32_t 	i,j;
 
 	// Jump to index of vidTrack
 	printf("Trying ODML super index..\n");
+#define szeof(x) printf("Sizeof "#x":%d\n",sizeof(x));        
+        szeof(OPENDML_INDEX);
+        szeof(OPENDML_ENTRY);
+        szeof(OPENML_SECONDARY_INDEX);
+        
+        
 	if(!_Tracks[track].indx.offset)
 	{
 		printf("No indx field.\n");
@@ -171,14 +181,23 @@ uint32_t 	i,j;
 		fseeko(_fd,superEntries[i].offset,SEEK_SET);
 		fcc=read32();
 		len=read32();
-		aprintf("subindex : %lu size %lu (%lx)",i,len,len);
+                aprintf("subindex : %lu size %lu (%lx)",i,len,len); 
+#ifdef CYG_MANGLING
+                aprintf("Seeking to %I64x\n",superEntries[i].offset);
+#else                             
+                aprintf("Seeking to %llx\n",superEntries[i].offset);
+#endif                
 		fourCC::print(fcc);aprintf("\n");
 		if(1!=fread(&second,sizeof(second),1,_fd))
 		{
 			printf("Problem reading secondary index \n");
 			return 0;
 		}	
+#ifdef CYG_MANGLING                
+                aprintf("Base : %I64x\n",second.base);
+#else                                
 		aprintf("Base : %llx\n",second.base);
+#endif                
 		uint32_t sizeflag;
 		for( j=0;j<second.nbEntryInUse;j++)
 		{
@@ -197,8 +216,16 @@ uint32_t 	i,j;
 					(*index)[count].intra=0;
 				else 
 					(*index)[count].intra=AVI_KEY_FRAME;
-				aprintf("Frame.off : %llx, size %llx\n",_idx[count].offset,
-									_idx[count].size);
+#ifdef CYG_MANGLING
+                                aprintf("Frame.off : %I64x, size %I64x\n",
+                                        _idx[count].offset,
+                                        _idx[count].size);
+#else                                        
+				aprintf("Frame.off : %llx, size %llx\n",
+                                        _idx[count].offset,
+                                        _idx[count].size);
+#endif                                
+                                                                        
 				count++;									
 			
 			}
