@@ -70,7 +70,7 @@ char stringFQ[60];
 		{
 		uint32_t ppCaps=0;
 		
-#ifdef USE_MMX	
+#if (defined( ARCH_X86)  || defined(ARCH_X86_64))
 		
 	#define ADD(x,y) if( CpuCaps::has##x()) ppCaps|=PP_CPU_CAPS_##y;
 		
@@ -102,7 +102,11 @@ void initPostProc(ADM_PP *pp,uint32_t w, uint32_t h)
 	memset(pp,0,sizeof(ADM_PP));
 	pp->w=w;
 	pp->h=h;
+#ifdef HAVE_ALTIVEC	
+	pp->fastMode=0;
+#else	
 	pp->fastMode=1;
+#endif	
 	aprintf("Initializing postproc\n");
 	
 
