@@ -61,7 +61,7 @@
 #include "../ADM_toolkit/ADM_debugID.h"
 #define MODULE_NAME MODULE_TCREQUANT
 #include "../ADM_toolkit/ADM_debug.h"
-
+#include "../ADM_assert.h"
 
 // / MEANX
 
@@ -88,6 +88,9 @@ static int verbose = 2;
 #ifdef CYG_MANGLING
 	#define uint unsigned int
 #endif
+#ifdef ADM_BSD_FAMILY
+	#define uint uint32_t
+#endif
 typedef unsigned char		uint8;
 typedef unsigned short		uint16;
 typedef unsigned int		uint32;
@@ -269,9 +272,9 @@ static uint64 cnt_b_i, cnt_b_ni;
 		mloka1 = rbuf - cbuf;\
 		if (mloka1) { COPY(mloka1); }\
 		WRITE \
-		free(orbuf); \
+		ADM_dealloc(orbuf); \
 		orbuf=NULL; \
-		free(owbuf); \
+		ADM_dealloc(owbuf); \
 		owbuf=NULL; \
 		\
 		LOG("Stats:\n");\
@@ -2131,8 +2134,8 @@ int Mrequant_init (float quant_factor,int byteStuffing)
 	byte_stuff = byteStuffing;
 
 	
-	rbuf = cbuf = orbuf = malloc(BUF_SIZE);
-	wbuf = owbuf = malloc(BUF_SIZE);
+	rbuf = cbuf = orbuf = ADM_alloc(BUF_SIZE);
+	wbuf = owbuf = ADM_alloc(BUF_SIZE);
 	
 	inbytecnt = outbytecnt = 0;
 
@@ -2392,7 +2395,7 @@ _req_exit:
 int Mrequant_end (void)
 {
 
-#define free_if(x) if(x){free(x);x=NULL;}
+#define free_if(x) if(x){ADM_dealloc(x);x=NULL;}
 	free_if(orbuf);
 	free_if(owbuf);
 	return 1;
