@@ -38,42 +38,6 @@
 
 //_________________________
 
-int scriptLoad(int n,Arg *args);
-int scriptExit(int n,Arg *args);
-int scriptAppend(int n,Arg *args);
-int scriptAudioProcess(int n,Arg *args);
-int scriptVideoProcess(int n,Arg *args);
-
-int scriptAudioDownsample(int n,Arg *args);
-int scriptAudioResample(int n,Arg *args);
-int scriptAudioNormalize(int n,Arg *args);
-
-int scriptLoadAudio(int n,Arg *args);
-int scriptSaveAudio(int n,Arg *args);
-int scriptGoto(int n,Arg *args);
-
-int scriptSetFps(int n,Arg *args);
-
-int scriptSleep(int n,Arg *args);
-int scriptSetMarkerA(int n,Arg *args);
-int scriptSetMarkerB(int n,Arg *args);
-int scriptScanVbr(int n,Arg *args);
-int scriptAudioDelay(int n,Arg *args);
-int scriptFilm2Pal(int n,Arg *args);
-int scriptAudioCodec(int n,Arg *args);
-int scriptLoadCodec(int n,Arg *args);
-int scriptSavejpeg(int n,Arg *args);
-int scriptRaw(int n,Arg *args);
-int scriptSave(int n,Arg *args);
-int scriptSaveDVD(int n,Arg *args);
-int scriptVideoCodec(int n,Arg *args);
-int scriptVideoCodec2(int n,Arg *args);
-int scriptSave(int n,Arg *args);
-int scriptLoadFilter(int n,Arg *args);
-int scriptAddVideoFilter(int n,Arg *args);
-int scriptRemoveFrame(int n,Arg *args);
-int scriptSaveOgm(int n, Arg *args);
-int scriptOutputFormat(int n, Arg *srgs);
 extern void HandleAction(Action act);
 //_________________________
 #include "adm_command.h" 
@@ -101,6 +65,23 @@ const ADM_CONTAINER container[]=
 };    
 #define NB_CONT sizeof(container)/sizeof(ADM_CONTAINER)
 
+
+extern uint8_t indexMpeg(char *mpeg,char *file,uint8_t aid);
+int scriptIndexMpeg(int n,Arg *args)
+{
+  char *in,*out;
+  uint32_t aid;
+  
+  aid=args[2].arg.integer;
+  
+  in=args[0].arg.string; 
+  out=args[1].arg.string;
+  
+  return indexMpeg(in,out,aid);
+  
+  
+  
+}
 int scriptOutputFormat(int n, Arg *args)
 {
     const char *str=args[0].arg.string;
@@ -127,6 +108,13 @@ VF_FILTERS filter;
 		
 }
 //___________________________
+extern uint8_t A_ListAllBlackFrames( char *file );
+int scriptScanBlackFrames(int n, Arg *args)
+{
+
+    return A_ListAllBlackFrames( args[0].arg.string );
+}
+//___________________________
 extern int ogmSave(char *name);
 int scriptSaveOgm(int n,Arg *args)
 {
@@ -139,9 +127,14 @@ extern int A_delete(uint32_t start, uint32_t end);
 int scriptRemoveFrame(int n,Arg *args)
 {
 uint32_t a,b;
-		a=args[0].arg.integer;
-		b=args[1].arg.integer;
-		return A_delete(a,b);
+	a=args[0].arg.integer;
+	b=args[1].arg.integer;
+             if(avifileinfo && a >= avifileinfo->nb_frames)
+                       a = avifileinfo->nb_frames-1;
+             if(avifileinfo && b >= avifileinfo->nb_frames)
+                       b = avifileinfo->nb_frames-1;
+		
+	return A_delete(a,b);
 }
 //_______________________
 extern int filterLoadXml(char *docname,uint8_t silent);
@@ -384,17 +377,17 @@ int scriptAudioResample(int n,Arg *args)
 	
 //________________________________________________
 extern uint8_t addFile(char *name);
-extern int A_openAvi2 (char *name, uint8_t mode);
+extern int A_appendAvi (char *name);
 int scriptAppend(int n,Arg *args)
 {
-	return A_openAvi2 (args[0].arg.string,0);
+  return A_appendAvi (args[0].arg.string);
 	
 }
 //________________________________________________
-
+extern int A_openAvi (char *name);
 int scriptLoad(int n,Arg *args)
 {	
-	return A_openAvi2 (args[0].arg.string,0);
+	return A_openAvi (args[0].arg.string);
 }
 //________________________________________________
 int scriptExit(int n,Arg *args)
