@@ -93,6 +93,7 @@
 #define YYSTYPE char * 
 #include "adm_yacgen.h"
 #include "adm_scanner.h" 
+#include "../ADM_assert.h" 
 
 
 /* Enabling traces.  */
@@ -149,8 +150,8 @@ typedef int YYSTYPE;
 #   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
 #   define YYSIZE_T size_t
 #  endif
-#  define YYSTACK_ALLOC malloc
-#  define YYSTACK_FREE free
+#  define YYSTACK_ALLOC ADM_alloc
+#  define YYSTACK_FREE ADM_dealloc
 # endif
 #endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */
 
@@ -1046,11 +1047,11 @@ yyreduce:
     {
 			if(!Call(yyvsp[-3]))
 			{
-				free(yyvsp[-3]); // don't need it anymore
+				ADM_dealloc(yyvsp[-3]); // don't need it anymore
 				YYABORT;
 			}
 			else
-				free(yyvsp[-3]); // don't need it anymore
+				ADM_dealloc(yyvsp[-3]); // don't need it anymore
 		;}
     break;
 
