@@ -83,7 +83,7 @@ DIR *dir=NULL;
 	}
 	else	//use pref
 	{
-		if( prefs->get(LASTDIR,&tmpname))
+		if( prefs->get(LASTDIR_READ,&tmpname))
 		{
 			
 	
@@ -147,6 +147,49 @@ void GUI_FileSelWrite(const char *label, char * * name)
     GUI_FileSel(label, NULL, 1,name);
 }
 
+// CYB 2005.02.23: DND
+void fileReadWrite(SELFILE_CB *cb, int rw, char *name)
+{
+
+	if(name)
+	{
+		if(cb)
+		{
+			FILE *fd;
+			fd=fopen(name,"rb");
+			if(rw==0) // read
+			{
+				// try to open it..
+				if(!fd)
+				{
+					GUI_Alert("Cannot open this file !");
+					return;
+				}
+			}
+			else // write
+			{
+				if(fd)
+				{
+					fclose(fd);
+					if(!GUI_Question("Overwrite file ?"))
+						return;
+				}
+				// check we have right access to it
+				fd=fopen(name,"wb");
+				if(!fd)
+				{
+					GUI_Alert("No write access to that file !");
+					return;
+				}
+			}
+			fclose(fd);
+			cb(name);
+			ADM_dealloc(name);
+		} // no callback -> return value
+	}
+}
+// CYB 2005.02.23: DND
+
 #if 1 || (GTK_MINOR_VERSION*10+GTK_MICRO_VERSION)<34
 
 void GUI_FileSel(const char *label, SELFILE_CB * cb, int rw,char **rname)
@@ -156,6 +199,7 @@ void GUI_FileSel(const char *label, SELFILE_CB * cb, int rw,char **rname)
 	char *name=NULL;
 	char *tmpname;
 	gchar *selected_filename;
+        uint8_t res;
 
 	if(rname)
 		*rname=NULL;
@@ -163,7 +207,11 @@ void GUI_FileSel(const char *label, SELFILE_CB * cb, int rw,char **rname)
 	dialog=create_fileselection1();
 	gtk_window_set_title (GTK_WINDOW (dialog),label);
 	gtk_transient(dialog);
-	if( prefs->get(LASTDIR,&tmpname))
+        if(rw)
+	       res=prefs->get(LASTDIR_WRITE,&tmpname); 
+        else
+               res=prefs->get(LASTDIR_READ,&tmpname); 
+        if(res)
 	{
 		DIR *dir;
 	//	printf("tmpname : %s\n",tmpname);
@@ -197,69 +245,25 @@ void GUI_FileSel(const char *label, SELFILE_CB * cb, int rw,char **rname)
 
 						char *str=PathCanonize(name);
 						PathStripName(str);
-						prefs->set(LASTDIR,str);			
+                                                if(rw)
+						  prefs->set(LASTDIR_WRITE,str);			
+                                                else
+                                                  prefs->set(LASTDIR_READ,str);                        
 						delete [] str;
 
 			}
 	}
 	gtk_widget_destroy(dialog);
 
-	if(name)
-	{
-
-		if(cb)
-		{
-
-			if(rw==0) // read
-			{
-				// try to open it..
-				FILE *fd;
-				fd=fopen(name,"rb");
-				if(!fd)
-				{
-						GUI_Alert("Cannot open this file !");
-						return;
-				}
-				fclose(fd);
-				cb(name);
-				ADM_dealloc(name);
-
-			}
-			else // write
-			{
-				FILE *fd;
-				fd=fopen(name,"rb");
-				if(fd)
-					{
-							fclose(fd);
-							if(!GUI_Question("Overwrite file ?"))
-								return;
-					}
-				// check we have right access to it
-				fd=fopen(name,"wb");
-				if(!fd)
-					{
-						GUI_Alert("No write access to that file !");
-						return;
-					}
-				fclose(fd);
-
-
-				cb(name);
-				ADM_dealloc(name);
-			}
-		} // no callback -> return value
-		else
-		{
-
-			*rname=name;
-
-
-		}
-
-
-	}
-
+// CYB 2005.02.23
+        if(cb)
+        {
+                fileReadWrite(cb, rw, name);
+        }
+        else
+        {
+                *rname=name;  
+        }
 }
 #else
 //
@@ -272,6 +276,7 @@ void GUI_FileSel(const char *label, SELFILE_CB * cb, int rw,char **rname)
 	char *name=NULL;
 	char *tmpname;
 	gchar *selected_filename;
+        uint8_t res;
 	GtkFileChooserAction action;
 	
 	if(rname)
@@ -286,8 +291,11 @@ void GUI_FileSel(const char *label, SELFILE_CB * cb, int rw,char **rname)
 				      GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 				      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				      NULL);
-				      
-	if( prefs->get(LASTDIR,&tmpname))
+        if(rw)
+                res=prefs->get(LASTDIR_WRITE,&tmpname)
+        else
+                res=prefs->get(LASTDIR_READ,&tmpname)
+	if(res)
 	{
 		char *str=PathCanonize(tmpname);
 		PathStripName(str);
@@ -317,68 +325,17 @@ void GUI_FileSel(const char *label, SELFILE_CB * cb, int rw,char **rname)
 
 						char *str=PathCanonize(name);
 						PathStripName(str);
-						prefs->set(LASTDIR,str);			
+                                                if(rw)
+						  prefs->set(LASTDIR_WRITE,str);
+                                                else
+                                                  prefs->set(LASTDIR_READ,str);                     
 						delete [] str;
 
 	}		}
 	gtk_widget_destroy (dialog);
 	
-	if(name)
-	{
-
-		if(cb)
-		{
-
-			if(rw==0) // read
-			{
-				// try to open it..
-				FILE *fd;
-				fd=fopen(name,"rb");
-				if(!fd)
-				{
-						GUI_Alert("Cannot open this file !");
-						return;
-				}
-				fclose(fd);
-				cb(name);
-				ADM_dealloc(name);
-
-			}
-			else // write
-			{
-				FILE *fd;
-				fd=fopen(name,"rb");
-				if(fd)
-					{
-							fclose(fd);
-							if(!GUI_Question("Overwrite file ?"))
-								return;
-					}
-				// check we have right access to it
-				fd=fopen(name,"wb");
-				if(!fd)
-					{
-						GUI_Alert("No write access to that file !");
-						return;
-					}
-				fclose(fd);
-
-
-				cb(name);
-				ADM_dealloc(name);
-			}
-		} // no callback -> return value
-		else
-		{
-
-			*rname=name;
-
-
-		}
-
-
-	}
-
+// CYB 2005.02.23
+    fileReadWrite(cb, rw, name);
 }
 
 #endif
