@@ -49,13 +49,16 @@
 #include "ADM_toolkit/ADM_debug.h"
 
 #include "ADM_filter/vidVCD.h"
+
+#include "ADM_script/adm_command.h"
+
 extern void filterListAll(void );
 extern void ADS_commandList( void );
 extern uint8_t loadVideoCodecConf( char *name);
 extern int A_saveJpg (char *name);
 extern void filterLoadXml(char *n);
-extern void A_openAvi(char *name);
-extern void A_appendAvi (char *name);
+extern int A_openAvi(char *name);
+extern int A_appendAvi (char *name);
 extern void A_saveAudio(char *name);
 extern int A_loadNone( void );
 extern void A_saveAudioDecodedTest(char *name);
@@ -73,11 +76,9 @@ extern void videoCodecSelectByName(const char *name);
 extern int videoCodecConfigure(char *p,uint32_t i, uint8_t  *c);
 #include "oplug_mpeg/op_mpeg.h"
 extern void encoderSetLogFile(char *name)     ;
-extern void A_loadWorkbench(char *name)     ;
 extern void updateLoaded( void );
 extern void setPostProc(int v,int s);
 extern void HandleAction(Action action) ;
-static  void load_workbench(char *name);;
 static void call_buildtimemap( char *p);
 static void call_audioproc(char *p) ;
 static void call_videoproc(char *p) ;
@@ -87,6 +88,8 @@ static void setEnd(char *p)      ;
 //static void saveRawAudio(char *p)      ;
 static void call_normalize(char *p) ;
 static void call_resample(char *p) 	;
+static void call_mono2stereo(char *p);
+static void call_stereo2mono(char *p);
 static void call_downsample(char *p) 	;
 static void call_help(char *p) 	;
 static void call_setAudio(char *p) 	;
@@ -101,7 +104,6 @@ static void call_videoconf(char *p) ;
 static int searchReactionTable(char *string);
 static void call_setPP(char *v,char *s);
 static void call_toolame(char *p);
-extern void A_loadWorkbench( char *name);
 extern void updateLoaded(void );
 extern void A_requantize2( float percent, uint32_t quality, char *out_name );
 static void save(char*name);
@@ -114,10 +116,17 @@ extern uint8_t ogmSave(char *fd);
 static void set_autoindex(char *p);
 extern int A_SaveUnpackedVop( char *name);
 extern int A_saveDVDPS(char *name);
+extern void A_saveWorkbench (char *name);
+extern uint8_t A_rebuildKeyFrame (void);
+extern uint8_t scriptAddVar(char *var,char *value);
 //
 static int call_bframe(void);
 static int call_packedvop(void);
 static int call_saveDVD(char *a);
+static int set_output_format(const char *str);
+static void setVar(char *in);
+//
+
 //_________________________________________________________________________
 
 extern uint8_t audioShift;
@@ -151,6 +160,8 @@ AUTOMATON reaction_table[]=
 		{"audio-normalize",	0,"activate normalization",		call_normalize},
 		{"audio-downsample",	0,"activate 48->44 downsampling",	call_downsample},
 		{"audio-resample",	1,"resample to x hz",			call_resample},
+		{"audio-mono2stereo",	0,"channel: convert mono to stereo",	call_mono2stereo},
+		{"audio-stereo2mono",	0,"channel: convert stereo tp mono",	call_stereo2mono},
 		
 		{"video-process",	0,"activate video processing",		call_videoproc},	
 		{"filters",		1,"load a filter preset",		filterLoadXml}   ,
@@ -171,10 +182,11 @@ AUTOMATON reaction_table[]=
 		{"save-uncompressed-audio",1,"save uncompressed audio",A_saveAudioDecodedTest},
 		{"index-mpeg",		3,"create index of vob/mpeg : vob.vob index.index audio#",
 								((one_arg_type )call_indexMpeg)},
-		{"load",		1,"load video",		A_openAvi},
-		{"append",		1,"append video",	A_appendAvi},
-		{"load-workbench",	1,"load workbench file",	load_workbench},
-		{"save",		1,"save avi",		save},		
+		{"load",		1,"load video or workbench",		(one_arg_type )A_openAvi},
+		{"load-workbench",	1,"load workbench file",		(one_arg_type)A_openAvi},
+		{"append",		1,"append video",			(one_arg_type)A_appendAvi},
+		{"save",		1,"save avi",				save},		
+		{"save-workbench",	1,"save workbench file",		(one_arg_type)A_saveWorkbench},
 		
 		{"force-b-frame",	0,"Force detection of bframe in next loaded file", (one_arg_type)call_bframe},
 		{"force-unpack",	0,"Force detection of packed vop in next loaded file"
@@ -201,7 +213,11 @@ AUTOMATON reaction_table[]=
 										(one_arg_type )call_requant},
 		{"info",		0	,"show information about loaded video and audio streams", show_info},
 		{"autoindex",		0	,"try to generate required index files", set_autoindex},
+		{"output-format",	1	,"set output format (AVI|OGM|ES|PS|AVI_DUAL|AVI_UNP|...)", (one_arg_type )set_output_format},
 		
+                {"rebuild-index",       0       ,"rebuild index with correct frame type", (one_arg_type)A_rebuildKeyFrame},
+
+                {"var",                 1       ,"set var (--var myvar=3)", (one_arg_type)setVar},
 		{"help",		0,"print this",		call_help},
 		{"quit",		0,"exit avidemux",	call_quit}
 
@@ -339,6 +355,28 @@ void call_downsample    (char *p)
 	printf("downsample\n");
 	 UNUSED_ARG(p); 
 
+}
+// The form is name=value
+// split it in two
+void setVar(char *in)
+{
+char *equal;
+        equal=strstr(in,"=");
+        if(!equal)
+        {
+                printf("Malformed set var  %s (name=value)\n",in);
+                return ;
+        }
+        if(in+strlen(in)==equal)
+        {
+                printf("No value after =  %s (name=value)\n",in);
+                return ;
+        }
+        *equal=0; // Remove =
+        
+        if(!scriptAddVar(in,equal+1))
+                printf("Warning setvar failed\n");        
+
 }
 void call_resample    (char *p)
 {
@@ -496,11 +534,6 @@ void call_requant(char *p, char *q, char *n)
 	i=atoi(q);
 	A_requantize2( f,i, n )	;
 }
-void load_workbench(char*name){
-   ADM_assert(name);
-   A_openAvi(name);
- //  updateLoaded();
-}
 
 void save(char*name)
 {
@@ -574,4 +607,30 @@ int call_packedvop(void)
 	return 1;
 }
 
+int set_output_format(const char *str){
+  Arg map;
+  int rc;
+	/* map to adm_script function and args */
+	/*
+	** JSC: have to change (const char*) to (char *) with max compatibility
+	** there are many dependencies if map.arg.string is changed to (char *) native
+	**    won't check them all :-)
+	*/
+	map.type = APM_STRING;
+	map.arg.string  = (char *)ADM_alloc(strlen(str)+1);
+	assert( map.arg.string );
+	strcpy( map.arg.string, str );
+	rc = scriptOutputFormat(-1,&map);
+	ADM_dealloc( map.arg.string );
+	return(rc);
+}
+
+void call_mono2stereo(char *p){
+   audioFilterMono2Stereo(1);
+}
+
+void call_stereo2mono(char *p){
+   audioFilterStereo2Mono(1);
+}
+
 //EOF
