@@ -70,7 +70,8 @@ extern uint8_t 	PutHintingData(unsigned char *video, unsigned int hint);
 extern uint8_t 	GetHintingData(unsigned char *video, unsigned int *hint);
 extern void 	BitBlt(uint8_t * dstp, int dst_pitch, const uint8_t* srcp,
             		int src_pitch, int row_size, int height);
-extern  void 	DrawString(uint8_t *dst, int x, int y, const char *s);
+extern  void 	DrawString(ADMImage *dst, int x, int y, const char *s);
+#define DrawString(a,b,c,d) DrawString(NULL,b,c,d)
 extern  void 	DrawStringYUY2(uint8_t *dst, int x, int y, const char *s); 
 
 
@@ -169,7 +170,7 @@ public:
 
 
 BUILD_CREATE(decimate_create,Decimate);
-extern void DrawString(uint8_t *dst, int x, int y, const char *s);
+
 /*
 PClip _child, int _cycle, int _mode, double _threshold, double _threshold2,
 				int _quality, const char * _ovr, bool _show, bool _debug, IScriptEnvironment* env) 
