@@ -35,6 +35,7 @@
 #include "ADM_toolkit/toolkit.hxx"
 #include "ADM_editor/ADM_edit.hxx"
 #include "ADM_video/ADM_genvideo.hxx"
+#include "admmangle.h"
 
 static int16_t scaletab[16];
 static uint64_t scaletab_MMX[65536];
@@ -66,11 +67,12 @@ SCRIPT_CREATE(fluxsmooth_script,ADMVideoFlux,fluxParam);
 //#define ASM_FLUX
 BUILD_CREATE(fluxsmooth_create,ADMVideoFlux);
 
-static uint64_t  spat_thresh,temp_thresh;
-static uint64_t  _l_counter_init,_l_indexer,_l_prev_pels,_l_next_pels;
-static int _l_src_pitch;
-static int _l_dst_pitch;
-static int _l_xmax;
+static uint64_t spat_thresh ASM_CONST =0LL;
+static uint64_t temp_thresh ASM_CONST =0LL;
+static uint64_t ASM_CONST _l_counter_init,_l_indexer,_l_prev_pels,_l_next_pels;
+static long int _l_src_pitch ASM_CONST =0;
+static long int _l_dst_pitch ASM_CONST =0;
+static int _l_xmax ASM_CONST=0;
 
 static int ycnt;
 static	uint8_t * _l_currp; 
@@ -262,14 +264,18 @@ ADMImage	*image,*next,*prev;
 	nextp += src_pitch;
 	destp += dst_pitch;
 
-	#if defined(USE_MMX) && defined(ASM_FLUX)
+	#if (defined( ARCH_X86)  || defined(ARCH_X86_64)) && defined(ASM_FLUX)
+        if(CpuCaps::hasMMX())
+        {
 		DoFilter_MMX(currp, prevp, nextp, src_pitch,
 			destp, dst_pitch, row_size, height - 2);
-	
-	#else
+	}else
+	#endif
+        {
 		DoFilter_C(currp, prevp, nextp, src_pitch,
 			destp, dst_pitch, row_size, height - 2);
-	#endif
+        }
+	
 	data->copyInfo(image);
 	vidCache->unlockAll();
 	return 1;
@@ -386,8 +392,7 @@ void ADMVideoFlux::DoFilter_C(
 	ADM_assert(ycnt == 0);
 
 }
-#ifdef USE_MMX
-#include "admmangle.h"
+#if (defined( ARCH_X86)  || defined(ARCH_X86_64))
 /*
 	__asm movq mm2, mm0 \
 	__asm movq mm3, mm1 \
@@ -445,23 +450,23 @@ uint8_t * currp,
 UNUSED_ARG(_l_prev_pels);
 UNUSED_ARG(_l_next_pels);
 asm(
-"								 movl (%0),%%esi \n\t"
-"                movl "Mangle(_l_currp)", %%esi \n\t"
-"                movl "Mangle(_l_destp)", %%edi \n\t"
+"								 mov (%0),"REG_si" \n\t"
+"                mov "Mangle(_l_currp)", "REG_si" \n\t"
+"                mov "Mangle(_l_destp)", "REG_di" \n\t"
 "                pxor %%mm7,%%mm7 \n\t"
 " \n\t"
 "yloop%=:  \n\t"
 "                # Copy first dword \n\t"
 " \n\t"
-"                movl (%%esi),%%eax \n\t"
-"                movl %%eax,(%%edi) \n\t"
+"                mov ("REG_si"),"REG_ax" \n\t"
+"                mov "REG_ax",("REG_di") \n\t"
 " \n\t"
-"                movl $4,%%ecx \n\t"
+"                mov $4,"REG_cx" \n\t"
 " \n\t"
 "xloop%=:  \n\t"
 "                # Get current pels, init sum and counter \n\t"
 " \n\t"
-"                movd (%%esi,%%ecx),%%mm0 \n\t"
+"                movd ("REG_si","REG_cx"),%%mm0 \n\t"
 "                punpcklbw %%mm7,%%mm0 \n\t"
 "                movq %%mm0,%%mm5 \n\t"
 "                movq "Mangle(_l_counter_init)",%%mm6 \n\t"
@@ -470,7 +475,7 @@ asm(
 " \n\t"
 "                movq %%mm0,%%mm1 \n\t"
 "                psllq $16,%%mm1 \n\t"
-"                movd -4(%%esi,%%ecx),%%mm2 \n\t"
+"                movd -4("REG_si","REG_cx"),%%mm2 \n\t"
 "                punpcklbw %%mm7,%%mm2 \n\t"
 "                psrlq $48,%%mm2 \n\t"
 "                por %%mm2,%%mm1 \n\t"
@@ -481,7 +486,7 @@ CHECK_AND_ADD(spat_thresh)
 " \n\t"
 "                movq %%mm0,%%mm1 \n\t"
 "                psrlq $16,%%mm1 \n\t"
-"                movd 4(%%esi,%%ecx),%%mm2 \n\t"
+"                movd 4("REG_si","REG_cx"),%%mm2 \n\t"
 "                punpcklbw %%mm7,%%mm2 \n\t"
 "                psllq $48,%%mm2 \n\t"
 "                por %%mm2,%%mm1 \n\t"
@@ -490,12 +495,12 @@ CHECK_AND_ADD(spat_thresh)
 " \n\t"
 "                # Top left \n\t"
 " \n\t"
-"                movl %%esi,%%eax \n\t"
-"                subl "Mangle(_l_src_pitch)", %%eax \n\t"
-"                movd (%%eax,%%ecx),%%mm1 \n\t"
+"                mov "REG_si","REG_ax" \n\t"
+"                sub "Mangle(_l_src_pitch)", "REG_ax" \n\t"
+"                movd ("REG_ax","REG_cx"),%%mm1 \n\t"
 "                punpcklbw %%mm7,%%mm1 \n\t"
 "                psllq $16,%%mm1 \n\t"
-"                movd -4(%%eax,%%ecx),%%mm2 \n\t"
+"                movd -4("REG_ax","REG_cx"),%%mm2 \n\t"
 "                punpcklbw %%mm7,%%mm2 \n\t"
 "                psrlq $48,%%mm2 \n\t"
 "                por %%mm2,%%mm1 \n\t"
@@ -504,7 +509,7 @@ CHECK_AND_ADD(spat_thresh)
 " \n\t"
 "                # Top centre \n\t"
 " \n\t"
-"                movd (%%eax,%%ecx),%%mm1 \n\t"
+"                movd ("REG_ax","REG_cx"),%%mm1 \n\t"
 "                punpcklbw %%mm7,%%mm1 \n\t"
 " \n\t"
 CHECK_AND_ADD(spat_thresh)
@@ -512,7 +517,7 @@ CHECK_AND_ADD(spat_thresh)
 "                # Top right \n\t"
 " \n\t"
 "                psrlq $16,%%mm1 \n\t"
-"                movd 4(%%eax,%%ecx),%%mm2 \n\t"
+"                movd 4("REG_ax","REG_cx"),%%mm2 \n\t"
 "                punpcklbw %%mm7,%%mm2 \n\t"
 "                psllq $48,%%mm2 \n\t"
 "                por %%mm2,%%mm1 \n\t"
@@ -521,12 +526,12 @@ CHECK_AND_ADD(spat_thresh)
 " \n\t"
 "                # Bottom left \n\t"
 " \n\t"
-"                movl %%esi,%%eax \n\t"
-"                addl "Mangle(_l_src_pitch)", %%eax \n\t"
-"                movd (%%eax,%%ecx),%%mm1 \n\t"
+"                mov "REG_si","REG_ax" \n\t"
+"                add "Mangle(_l_src_pitch)", "REG_ax" \n\t"
+"                movd ("REG_ax","REG_cx"),%%mm1 \n\t"
 "                punpcklbw %%mm7,%%mm1 \n\t"
 "                psllq $16,%%mm1 \n\t"
-"                movd -4(%%eax,%%ecx),%%mm2 \n\t"
+"                movd -4("REG_ax","REG_cx"),%%mm2 \n\t"
 "                punpcklbw %%mm7,%%mm2 \n\t"
 "                psrlq $48,%%mm2 \n\t"
 "                por %%mm2,%%mm1 \n\t"
@@ -535,7 +540,7 @@ CHECK_AND_ADD(spat_thresh)
 " \n\t"
 "                # Bottom centre \n\t"
 " \n\t"
-"                movd (%%eax,%%ecx),%%mm1 \n\t"
+"                movd ("REG_ax","REG_cx"),%%mm1 \n\t"
 "                punpcklbw %%mm7,%%mm1 \n\t"
 " \n\t"
 CHECK_AND_ADD(spat_thresh)
@@ -543,7 +548,7 @@ CHECK_AND_ADD(spat_thresh)
 "                # Bottom right \n\t"
 " \n\t"
 "                psrlq $16,%%mm1 \n\t"
-"                movd 4(%%eax,%%ecx),%%mm2 \n\t"
+"                movd 4("REG_ax","REG_cx"),%%mm2 \n\t"
 "                punpcklbw %%mm7,%%mm2 \n\t"
 "                psllq $48,%%mm2 \n\t"
 "                por %%mm2,%%mm1 \n\t"
@@ -552,8 +557,8 @@ CHECK_AND_ADD(spat_thresh)
 " \n\t"
 "                # Previous frame \n\t"
 " \n\t"
-"                movl "Mangle(_l_prevp)", %%eax \n\t"
-"                movd (%%eax,%%ecx),%%mm1 \n\t"
+"                mov "Mangle(_l_prevp)", "REG_ax" \n\t"
+"                movd ("REG_ax","REG_cx"),%%mm1 \n\t"
 "                punpcklbw %%mm7,%%mm1 \n\t"
 "                movq %%mm1, "Mangle(_l_prev_pels)" \n\t"
 " \n\t"
@@ -561,8 +566,8 @@ CHECK_AND_ADD(temp_thresh)
 " \n\t"
 "                # Next frame \n\t"
 " \n\t"
-"                movl "Mangle(_l_nextp)", %%eax \n\t"
-"                movd (%%eax,%%ecx),%%mm1 \n\t"
+"                mov "Mangle(_l_nextp)", "REG_ax" \n\t"
+"                movd ("REG_ax","REG_cx"),%%mm1 \n\t"
 "                punpcklbw %%mm7,%%mm1 \n\t"
 "                movq %%mm1, "Mangle(_l_next_pels)" \n\t"
 " \n\t"
@@ -576,11 +581,11 @@ CHECK_AND_ADD(temp_thresh)
 "                pmaddwd "Mangle(_l_indexer)",%%mm6                  # Make index into lookup \n\t"
 "                movq %%mm6,%%mm1 \n\t"
 "                punpckhdq %%mm6,%%mm6 \n\t"
-"                movl "Mangle(scaletab_MMX)", %%eax \n\t"
+"                mov "Mangle(scaletab_MMX)", "REG_ax" \n\t"
 "                paddd %%mm6,%%mm1 \n\t"
-"                movd %%mm1,%%ebx \n\t"
+"                movd %%mm1,"REG_bx" \n\t"
 " \n\t"
-"            movq (%%eax,%%ebx,8),%%mm2          # Do lookup \n\t"
+"            movq ("REG_ax","REG_bx",8),%%mm2          # Do lookup \n\t"
 "            pmulhw %%mm2,%%mm5                                  # mm5 = average \n\t"
 " \n\t"
 "                # Apply smoothing only to fluctuating pels \n\t"
@@ -607,29 +612,29 @@ CHECK_AND_ADD(temp_thresh)
 "                # Store \n\t"
 " \n\t"
 "                packuswb %%mm7,%%mm1 \n\t"
-"                movntq %%mm1,(%%edi,%%ecx) \n\t"
+"                movntq %%mm1,("REG_di","REG_cx") \n\t"
 " \n\t"
 "                # Advance \n\t"
 " \n\t"
-"                addl $4,%%ecx \n\t"
-"                cmpl "Mangle(_l_xmax)", %%ecx \n\t"
+"                add $4,"REG_cx" \n\t"
+"                cmp "Mangle(_l_xmax)", "REG_cx" \n\t"
 "                jl xloop%= \n\t"
 " \n\t"
 "                # Copy last dword \n\t"
 " \n\t"
-"                movl (%%esi,%%ecx),%%eax \n\t"
-"                movl %%eax,(%%edi,%%ecx) \n\t"
+"                mov ("REG_si","REG_cx"),"REG_ax" \n\t"
+"                mov "REG_ax",("REG_di","REG_cx") \n\t"
 " \n\t"
 "                # Next row \n\t"
 " \n\t"
-"                addl "Mangle(_l_src_pitch)", %%esi \n\t"
-"                movl "Mangle(_l_prevp)", %%eax \n\t"
-"                addl "Mangle(_l_src_pitch)", %%eax \n\t"
-"                movl %%eax, "Mangle(_l_prevp)" \n\t"
-"                movl "Mangle(_l_nextp)", %%ebx \n\t"
-"                addl "Mangle(_l_src_pitch)", %%ebx \n\t"
-"                movl %%ebx, "Mangle(_l_nextp)" \n\t"
-"                addl "Mangle(_l_dst_pitch)", %%edi \n\t"
+"                add "Mangle(_l_src_pitch)", "REG_si" \n\t"
+"                mov "Mangle(_l_prevp)", "REG_ax" \n\t"
+"                add "Mangle(_l_src_pitch)", "REG_ax" \n\t"
+"                mov "REG_ax", "Mangle(_l_prevp)" \n\t"
+"                mov "Mangle(_l_nextp)", "REG_bx" \n\t"
+"                add "Mangle(_l_src_pitch)", "REG_bx" \n\t"
+"                mov "REG_bx", "Mangle(_l_nextp)" \n\t"
+"                add "Mangle(_l_dst_pitch)", "REG_di" \n\t"
 " \n\t"
 "                sub $1, "Mangle(ycnt)" \n\t"
 "                jnz yloop%= \n\t"
