@@ -39,13 +39,14 @@
 
 
 
-#ifdef USE_MMX
+#if (defined( ARCH_X86)  || defined(ARCH_X86_64))
 extern "C" {
 #include "../../adm_lavcodec/avcodec.h"
 }
 #endif
 
-#include "ADM_video/swscale.h"
+#include "../MPlayer_pp/img_format.h"
+#include "../MPlayer_pp/swscale.h"
 #include "ADM_toolkit/ADM_cpuCap.h"
 #include "ADM_filter/video_filters.h"
 
@@ -185,7 +186,7 @@ uint8_t AVDMVideoStreamMPResize::reset(uint32_t nw, uint32_t old,uint32_t algo)
 						default:ADM_assert(0);
 
 					}
-#ifdef USE_MMX
+#if (defined( ARCH_X86)  || defined(ARCH_X86_64))
 		
 		#define ADD(x,y) if( CpuCaps::has##x()) flags|=SWS_CPU_CAPS_##y;
 		ADD(MMX,MMX);		
@@ -200,7 +201,7 @@ uint8_t AVDMVideoStreamMPResize::reset(uint32_t nw, uint32_t old,uint32_t algo)
 						IMGFMT_YV12,
 		 				nw,old,
 	   					IMGFMT_YV12,
-	    					flags, srcFilter, dstFilter);
+	    					flags, srcFilter, dstFilter,NULL);
 
 				if(!_context) return 0;
 				return 1;
