@@ -74,14 +74,17 @@ extern uint8_t 	PutHintingData(unsigned char *video, unsigned int hint);
 extern uint8_t 	GetHintingData(unsigned char *video, unsigned int *hint);
 extern void 	BitBlt(uint8_t * dstp, int dst_pitch, const uint8_t* srcp,
             		int src_pitch, int row_size, int height);
-extern  void 	DrawString(uint8_t *dst, int x, int y, const char *s);
+//extern  void 	DrawString(uint8_t *dst, int x, int y, const char *s);
+extern  void    DrawString(ADMImage *dst, int x, int y, const char *s);
+#define DrawString(a,b,c,d) DrawString(NULL,b,c,d)
+
 extern  void 	DrawStringYUY2(uint8_t *dst, int x, int y, const char *s); 
 
 static void Blur_C(uint8_t *in, uint8_t *out, uint32_t w, uint32_t h) ;
 #ifdef HAVE_ALTIVEC
 void Blur_Altivec(uint8_t *in, uint8_t *out, uint32_t w, uint32_t h);
 #endif
-#ifdef USE_MMX
+#if (defined( ARCH_X86)  || defined(ARCH_X86_64))
 void Blur_MMX(uint8_t *in, uint8_t *out, uint32_t w, uint32_t h);
 #endif
 class Msmooth : public AVDMGenericVideoStream
@@ -474,7 +477,7 @@ int16_t  v16[8];
 }
 #endif
 
-#ifdef USE_MMX
+#if (defined( ARCH_X86)  || defined(ARCH_X86_64))
 //______________________
 void Blur_MMX(uint8_t *in, uint8_t *out, uint32_t w, uint32_t h)
 {
@@ -592,9 +595,9 @@ void  Msmooth::EdgeMaskYV12(const unsigned char *srcp, unsigned char *blurp, uns
 	int y1, y2, y3, y4;
 
 	/* Blur the source image prior to detail detection. */
-	#if defined(USE_MMX)
+#if (defined( ARCH_X86)  || defined(ARCH_X86_64))
 		//printf("MMX\n");
-	if(1)
+	if(CpuCaps::hasMMX())
 	{
 		Blur_MMX((uint8_t *)srcp,(uint8_t *)workp,row_size,height);
 		Blur_MMX((uint8_t *)workp,(uint8_t *)blurp,row_size,height);
