@@ -17,6 +17,7 @@
  // This is used to test new features
  // should be commented out for regulat build
 //#define TEST_MP2
+#define TEST_OCR
 #ifdef TEST_MP2
 	#warning TEST_MP2 is ON
 	#warning TEST_MP2 is ON
@@ -104,10 +105,10 @@ int A_loadNone( void );
 void A_saveAudioDecodedTest (char *name);
 void A_openBrokenAvi (char *name);
 int A_openAvi2 (char *name, uint8_t mode);
-void A_appendAvi (char *name);
+int A_appendAvi (char *name);
 extern void A_SaveAudioNVideo (char *name);
 void HandleAction (Action action);
-void A_rebuildKeyFrame (void);
+uint8_t A_rebuildKeyFrame (void);
 extern int GUI_handleFilter (void);
 extern void filterCleanUp (void);
 int A_audioSave(char *name);
@@ -143,18 +144,20 @@ void computeIT (int size, int nb, int brate, uint32_t * frame,
 		uint32_t * rsize);
 int ADM_saveRaw (char *name);
 static char * actual_workbench_file;
-static void A_saveWorkbench (char *name);
+void A_saveWorkbench (char *name);
 void updateLoaded (void);
 extern void encoderSetLogFile (char *name);
 extern void videoCodecSelect (void);
 extern uint8_t DIA_about( void );
 extern uint8_t DIA_RecentFiles( char **name );
-extern void mpeg_passthrough(  char *name );
+extern void mpeg_passthrough(  char *name,ADM_OUT_FORMAT format );
 static void A_videoCheck( void);
 extern void parseScript(char *scriptname);
 int A_saveDVDPS(char *name);
 static void	A_setPostproc( void );
 extern uint8_t ogmSave(char  *name);
+//
+static uint8_t A_pass(char *name);
 //__________
 extern uint8_t ogmSave(char *fd);
 extern uint8_t GUI_getFrame(uint32_t frameno, ADMImage *image, uint32_t *flags);
@@ -165,6 +168,8 @@ extern void videoCodecChanged(int newcodec);
 extern void DIA_Calculator(uint32_t *sizeInMeg, uint32_t *avgBitrate );
 extern int ignore_change;
 
+extern uint8_t ADM_ocr_engine( void);
+
 PARAM_MUX muxMode = MUX_REGULAR;
 int muxParam = 0;
 
@@ -179,8 +184,7 @@ extern int audioDelay;
 // QT or other port should be easy
 //___________________________________________
 
-void
-HandleAction (Action action)
+void HandleAction (Action action)
 {
   static int recursive = 0;
 
@@ -192,6 +196,9 @@ HandleAction (Action action)
 
   switch (action)
     {
+      case ACT_Ocr:
+                ADM_ocr_engine( );
+                return;
       case ACT_AudioConfigure:
     		audioCodecSelect();
 		return;
@@ -393,7 +400,7 @@ HandleAction (Action action)
   // allow all actions
 
   // restict disabled uncoded actions
-  if ((int) action > 100)
+  if ((int) action > 160)
     {
       GUI_Alert ("Not coded on this version");
       return;
@@ -407,7 +414,7 @@ HandleAction (Action action)
 
 
 	case ACT_OpenAvi:
-	  GUI_FileSelRead ("Select AVI file...", A_openAvi);
+          GUI_FileSelRead ("Select AVI file...", (SELFILE_CB *)A_openAvi);
 	  break;
 
 	case ACT_BrokenAvi:
@@ -512,13 +519,13 @@ case ACT_Pipe2Other:
       break;
 
     case ACT_OpenAvi:
-      GUI_FileSelRead ("Select AVI file...", A_openAvi);
+      GUI_FileSelRead ("Select AVI file...",(SELFILE_CB *) A_openAvi);
       break;
     case ACT_BrokenAvi:
       GUI_FileSelRead ("Select AVI file...", A_openBrokenAvi);
       break;
     case ACT_AppendAvi:
-      GUI_FileSelRead ("Select AVI file to append...", A_appendAvi);
+      GUI_FileSelRead ("Select AVI file to append...",(SELFILE_CB *) A_appendAvi);
       break;
     case ACT_SaveWave:
       	{
@@ -618,7 +625,10 @@ case ACT_Pipe2Other:
     case ACT_PrevBlackFrame:
       GUI_NextPrevBlackFrame(-1);
       break;
-
+    case ACT_AllBlackFrames:    
+       GUI_FileSelWrite ("Select file to save", (SELFILE_CB *)A_ListAllBlackFrames);
+        break;                        
+    
     case ACT_PreviousFrame:
       if (curframe)
 	{
@@ -872,10 +882,10 @@ A_openBrokenAvi (char *name)
   A_openAvi2 (name, 1);
 }
 
-void
+int
 A_openAvi (char *name)
 {
-  A_openAvi2 (name, 0);
+  return A_openAvi2 (name, 0);
 }
 extern void GUI_PreviewEnd (void);
 int A_openAvi2 (char *name, uint8_t mode)
@@ -1076,19 +1086,19 @@ void  updateLoaded ()
 //___________________________________________
 //  Append an AVI to the existing one
 //___________________________________________
-void
+int
 A_appendAvi (char *name)
 {
 
 
   if (playing)
-    return;
+    return 0;
   DIA_StartBusy ();
   if (!video_body->addFile (name))
     {
       DIA_StopBusy ();
       GUI_Alert ("Something failed ...");
-      return;
+      return 0;
     }
   DIA_StopBusy ();
 
@@ -1097,10 +1107,11 @@ A_appendAvi (char *name)
   if (!video_body->updateVideoInfo (avifileinfo))
     {
       GUI_Alert ("Something bad happened (II)...");
+      return 0;
     }
 
   ReSync ();
-
+  return 1;
 }
 
 //
@@ -1771,7 +1782,7 @@ extern void getCutPoints (int br);
 void
 ADM_cutWizard (void)
 {
-
+#if 0
   int br;
   if (currentaudiostream)
     {
@@ -1781,7 +1792,7 @@ ADM_cutWizard (void)
     br = 128;
 
   getCutPoints (br);
-
+#endif
 }
 
 void
@@ -2160,13 +2171,18 @@ int A_saveDVDPS(char *name)
 				}
 				printf("Using pass through\n");
 				if(!name)
-					GUI_FileSelWrite ("Select Mpeg file...", mpeg_passthrough);
+					GUI_FileSelWrite ("Select Mpeg file...", (SELFILE_CB *)A_pass);
 				else
-					mpeg_passthrough(name);
+					mpeg_passthrough(name,ADM_PS);
 			}
 
 	return 1;
 }
+uint8_t A_pass(char *name)
+{
+        mpeg_passthrough(name,ADM_PS);
+        return 1;
+}
 int A_delete(uint32_t start, uint32_t end)
 {
 uint32_t count;
