@@ -48,9 +48,10 @@ typedef void *FCT_VOID(void *);
 
 #ifdef USE_FFMPEG
      extern "C" {
-     extern void     avcodec_init(void );
+     extern void        avcodec_init(void );
      extern  void 	avcodec_register_all(void );
      extern  int 	mpegps_init(void );
+     extern uint8_t     ADM_InitMemcpy(void);
                        };
 #endif                       
 
@@ -80,10 +81,11 @@ extern void     VPInitLibrary();
 };
 
 void sig_segfault_handler(int signo);
+
 extern void ADMImage_stat( void );
 int global_argc;
 char **global_argv;
-
+int CpuCaps::myCpuCaps=0;
 int main(int argc, char *argv[])
 {
 // Check for big files
@@ -122,8 +124,8 @@ printf("\n LARGE FILE AVAILABLE : %d offset\n",  __USE_FILE_OFFSET64	);
 	printf(" FreeBsd   : Anish Mistry, amistry@am-productions.biz\n");
 
 
-#ifdef USE_MMX
-	printf("MMX activated.\n"); 	
+#if (defined( ARCH_X86)  || defined(ARCH_X86_64))
+	printf("Arcc X86 X86_64 activated.\n"); 	
 #endif
    
 
@@ -135,6 +137,9 @@ printf("\n LARGE FILE AVAILABLE : %d offset\n",  __USE_FILE_OFFSET64	);
    register_Encoders( );
     atexit(onexit);
 
+#ifndef CYG_MANGLING    
+    g_thread_init(NULL);
+#endif
     gtk_set_locale();
     gtk_init(&argc, &argv);
     gdk_rgb_init();
@@ -142,6 +147,7 @@ printf("\n LARGE FILE AVAILABLE : %d offset\n",  __USE_FILE_OFFSET64	);
 	xvid4_init();
 #endif
 	CpuCaps::init();
+	ADM_InitMemcpy();
    if(!initGUI())
     	{
 		printf("\n Fatal : could not init GUI\n");
