@@ -14,6 +14,11 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+ 
+ /*
+* MODIFIED BY GMV 30.1.05: prepared for ODML
+*/
+ 
 #include "config.h"
 
 #include <stdio.h>
@@ -333,6 +338,7 @@ GenericAviSave::guiStart (void)
 	encoding_gui=new DIA_encoding(25000);
 	encoding_gui->setCodec("Copy");
 	encoding_gui->setFrame (0, 100);
+        encoding_gui->setContainer("Avi");
 
 }
 
@@ -382,6 +388,10 @@ uint8_t  GenericAviSave::handleMuxSize ( void )
 //
 uint8_t   GenericAviSave::reigniteChunk( uint32_t dataLen, uint8_t *data )
 {
+	// MOD Feb 2005 by GMV: ODML exit
+	if(writter->doODML!=aviWrite::NO)return 1;	// exit if odml has to be used
+	// END MOD Feb 2005 by GMV
+	
 	    // first end up the current chunk
 	     	writter->setEnd ();
   			delete       writter;
@@ -456,6 +466,7 @@ const char *getStrFromAudioCodec( uint32_t codec)
 		case (WAV_AMRNB): return (const char *)"AMR narrow band";
 		case (WAV_MSADPCM): return (const char *)"MSADPCM";
 		case (WAV_ULAW): return (const char *)"ULAW";
+                case WAV_8BITS_UNSIGNED:return (const char *)"PCM 8bits";
 	}
 
 	return (const char *)"Unknown codec";
