@@ -26,11 +26,12 @@
 //#include "aviaudio.hxx"
 #include "ADM_audiofilter/audioprocess.hxx"
 #include <ADM_assert.h>
-#include "ADM_dialog/DIA_working.h"
+#include "ADM_dialog/DIA_encoding.h"
 
 #include "ADM_audiofilter/audioeng_buildfilters.h"
 #include "prefs.h"
 #include "ADM_toolkit/toolkit.hxx"
+#include "ADM_editor/ADM_outputfmt.h"
 #include "ADM_lavformat/ADM_lavformat.h"
 
 #include "ADM_lvemux/ADM_muxer.h"
@@ -58,30 +59,30 @@
 			printf("passthrough:Could not get audio\n"); \
 			break; \
 		}\
-		if(audiolen) \
+		if(audiolen) {\
 			muxer->writeAudioPacket(audiolen,buffer); \
+                        work->feedAudioFrame(audiolen);\
+                        }\
 		total_got+=audiolen; \
 	} \
 }
 
 uint8_t isMpeg12Compatible(uint32_t fourcc);
- 
-void mpeg_passthrough(  char *name )
+extern const char *getStrFromAudioCodec( uint32_t codec); 
+void mpeg_passthrough(  char *name,ADM_OUT_FORMAT format )
 {
   uint32_t len, flags;
   AVDMGenericAudioStream *audio=NULL;
   uint32_t audiolen;
   uint8_t *buffer = new uint8_t[avifileinfo->width * avifileinfo->height * 3];
   
-  DIA_working *work;
+  DIA_encoding *work;
   ADM_MUXER_TYPE mux;
   
   double total_wanted=0;
   double total_got=0;
  
- //#define MYMUXER MpegMuxer
- #define MYMUXER lavMuxer
-  MYMUXER *muxer=NULL;
+  ADMMpegMuxer *muxer=NULL;
   
   	printf("Saving as mpg PS to file %s\n",name);
   
@@ -97,7 +98,12 @@ void mpeg_passthrough(  char *name )
 		return ;
   	}
   
-	
+	ADM_assert (video_body->getFlags (frameStart, &flags));
+        if(!(flags&AVI_KEY_FRAME))
+        {
+                GUI_Alert("The first frame must be intra\nin copy mode!\n");
+                return ;
+        }
 	
   	audio=mpt_getAudioStream();
 	
@@ -139,42 +145,69 @@ void mpeg_passthrough(  char *name )
 		isMpeg1=0;
 	
 	}
-	if(isMpeg1)
-	{
-		if(hdr->frequency!=44100 ||  hdr->encoding != WAV_MP2)
-		{
-			GUI_Alert("This is not compatible with VCD mpeg.\n");
-			return ;
-		}
-		mux=MUXER_VCD;
-		printf("PassThrought: Using VCD PS\n");
 	
-	}else
-	{    
-		aviInfo info;
-		video_body->getVideoInfo(&info);
-		if(hdr->frequency==44100 && info.width==480&&hdr->encoding == WAV_MP2 ) // SVCD ?
-		{
-			mux=MUXER_SVCD;
-			printf("PassThrought: Using SVCD PS\n");
-		}
-		else
-		{
-			 // mpeg2, we do only DVD right now
-			if(hdr->frequency!=48000 || 
-			(hdr->encoding != WAV_MP2 && hdr->encoding!=WAV_AC3))
-			{
-				deleteAudioFilter();
-				GUI_Alert("Audio track is not suitable!\n");
-				return ;
-			}
-		mux=MUXER_DVD;
-		printf("PassThrought: Using DVD PS\n");
-		}
-	}
-	
-	
-  	muxer=new MYMUXER();
+	switch(format)
+        {
+        case ADM_PS:	
+                if(isMpeg1)
+                {
+                        if(hdr->frequency!=44100 ||  hdr->encoding != WAV_MP2)
+                        {
+                                GUI_Alert("This is not compatible with VCD mpeg.\n");
+                                return ;
+                        }
+                        mux=MUXER_VCD;
+                        printf("PassThrought: Using VCD PS\n");        
+                        }else
+                {    
+                        aviInfo info;
+                        video_body->getVideoInfo(&info);
+                        if(hdr->frequency==44100 && info.width==480&&hdr->encoding == WAV_MP2 ) // SVCD ?
+                        {
+                                mux=MUXER_SVCD;
+                                printf("PassThrought: Using SVCD PS\n");
+                        }
+                        else
+                        {
+                                 // mpeg2, we do only DVD right now
+                                if(hdr->frequency!=48000 || 
+                                (hdr->encoding != WAV_MP2 && hdr->encoding!=WAV_AC3))
+                                {
+                                        deleteAudioFilter();
+                                        GUI_Alert("Audio track is not suitable!\n");
+                                        return ;
+                                }
+                                mux=MUXER_DVD;
+                                printf("PassThrought: Using DVD PS\n");
+                        }
+                }
+
+  	        muxer=new mplexMuxer();
+#if 0
+#warning TEST
+#warning TEST
+#warning TEST
+#warning TEST
+#warning TEST
+#warning TEST
+                muxer=new lavMuxer();
+#endif
+                break;
+        case ADM_TS:     
+             printf("Using TS output format\n");   
+             muxer=new tsMuxer(); //lavMuxer();
+             mux=MUXER_TS;
+             break;
+        default:
+                ADM_assert(0);
+                break;
+        }
+        
+        if(!muxer)
+         {
+                 printf("No muxer ?\n");
+                 return ;
+        }
 	if(!muxer->open(name,0,mux,avifileinfo,audio->getInfo()))
 	{
 		delete muxer;
@@ -183,11 +216,27 @@ void mpeg_passthrough(  char *name )
 		return ;
 		
 	}
+        
 	// In copy mode it is better to recompute the gop timestamp
 	muxer->forceRestamp();
   ///____________________________
-  work=new DIA_working("Saving MpegPS stream");
-
+  work=new DIA_encoding(avifileinfo->fps1000);
+  work->setCodec("Copy");
+  work->setAudioCodec("---");
+  work->setPhasis("Saving");
+  if(!audioProcessMode)
+     work->setAudioCodec("Copy");
+  else
+     work->setAudioCodec(getStrFromAudioCodec(audio->getInfo()->encoding));
+  switch(mux)
+  {
+    case MUXER_TS: work->setContainer("Mpeg TS");break;
+    case MUXER_VCD: work->setContainer("Mpeg VCD");break;
+    case MUXER_SVCD: work->setContainer("Mpeg SVCD");break;
+    case MUXER_DVD: work->setContainer("Mpeg DVD");break;
+    default:
+        ADM_assert(0);
+  }
   // preamble
   /*
   video_body->getRawStart (frameStart, buffer, &len);
@@ -197,12 +246,13 @@ void mpeg_passthrough(  char *name )
 // 	{
 //   		PACK_AUDIO(0)
 // 	}
+  PACK_AUDIO(0)
   uint32_t cur=0;
   for (uint32_t i = frameStart; i < frameEnd; i++)
     {
       
+      work->setFrame(i - frameStart, frameEnd - frameStart);
       
-      work->update (i - frameStart, frameEnd - frameStart);
       if(!work->isAlive()) goto _abt;
       ADM_assert (video_body->getFlags (i, &flags));
       if (flags & AVI_B_FRAME)	// oops
@@ -225,6 +275,7 @@ void mpeg_passthrough(  char *name )
 	video_body->getRaw (found, buffer, &len);
 	
 	muxer->writeVideoPacket (len,buffer,cur++,found-frameStart);	
+        work->feedFrame(len);
 	PACK_AUDIO(0)
 	
 	  
@@ -234,6 +285,7 @@ void mpeg_passthrough(  char *name )
 		video_body->getRaw (j, buffer, &len);
 		
 		muxer->writeVideoPacket (len,buffer,cur++,j-frameStart);
+                work->feedFrame(len);
 		PACK_AUDIO(0)
 		
     	    }
@@ -248,6 +300,7 @@ void mpeg_passthrough(  char *name )
 			if(buffer[0]==0 && buffer[1]==0 && buffer[2]==1 && buffer[3]==0xb3) // Seq start
 			{
 				muxer->writeVideoPacket (len,buffer,cur++,i-frameStart);
+                                work->feedFrame(len);
 				PACK_AUDIO(0)
 				
 				
@@ -259,6 +312,7 @@ void mpeg_passthrough(  char *name )
 	  			video_body->getRaw (i, buffer+seq, &len);
 				
 				muxer->writeVideoPacket (len+seq,buffer,cur++,i-frameStart);
+                                work->feedFrame(len);
 				PACK_AUDIO(0)
 				
 			}
@@ -268,6 +322,7 @@ void mpeg_passthrough(  char *name )
 			video_body->getRaw (i, buffer, &len);
 			
 			muxer->writeVideoPacket (len,buffer,cur++,i-frameStart);
+                        work->feedFrame(len);
 			PACK_AUDIO(0)
 			
 		}
