@@ -116,12 +116,12 @@ mpegWritter::mpegWritter( void )
 	_audio=NULL;
 	_audioBuffer=NULL;
 	_muxer=NULL;
-	_outputAsPs=0;
+	_outputAs=MUXER_NONE;        
 	audioWanted=audioGot=0;
 	_ratecontrol=NULL;
 
 }
-mpegWritter::mpegWritter( uint8_t ps )
+mpegWritter::mpegWritter( ADM_MUXER_TYPE ps )
 {	
 	_w=_h=0;
 	_fps1000=0;
@@ -132,7 +132,8 @@ mpegWritter::mpegWritter( uint8_t ps )
 	_audio=NULL;
 	_audioBuffer=NULL;
 	_muxer=NULL;
-	_outputAsPs=ps;
+        _outputAs=ps;
+        
 	audioWanted=audioGot=0;
 	_ratecontrol=NULL;
 
@@ -148,11 +149,12 @@ mpegWritter::~mpegWritter(  )
 /*---------------------------------------------------------------------------------------*/
 uint8_t  mpegWritter::save_svcd(char *name)
 {
-	if(_outputAsPs)
+	if(_outputAs)
 	{
-		switch(_outputAsPs)
+		switch(_outputAs)
 		{
-			case 2:
+                        
+			case MUXER_SVCD:
 				if(!initLveMux(name,MUXER_SVCD))
 					return 0;
 				break;
@@ -225,11 +227,15 @@ AVDMGenericAudioStream 	*tmp=NULL;
 WAVHeader		*info=NULL,tmpinfo;	
 
 	// look if we have a suitable audio
-	if(_outputAsPs)
+	if(_outputAs)
 	{
-		switch(_outputAsPs)
+		switch(_outputAs)
 		{
-			case 1:
+                        case MUXER_TS:
+                                if(!initLveMux(name,MUXER_TS))
+                                        return 0;
+                                break;
+			case MUXER_DVD:
 				if(!initLveMux(name,MUXER_DVD))
 					return 0;
 				break;
@@ -287,11 +293,11 @@ uint8_t  mpegWritter::save_vcd(char *name)
 {
 
 // look if we have a suitable audio
-	if(_outputAsPs)
+	if(_outputAs)
 	{
-		switch(_outputAsPs)
+		switch(_outputAs)
 		{
-			case 2:
+			case MUXER_VCD:
 				if(!initLveMux(name,MUXER_VCD))
 					return 0;
 				break;
@@ -417,8 +423,24 @@ DIA_encoding		*encoding;
 	printf("\n--encoding started--\n");
 	if(_muxer)
 	{
-		 encoding->setAudioCodec(getStrFromAudioCodec(_audio->getInfo()->encoding));	
+            if(audioProcessMode)
+                encoding->setAudioCodec(getStrFromAudioCodec(_audio->getInfo()->encoding));
+            else
+                encoding->setAudioCodec("Copy");
+            switch(_outputAs)
+            {
+                
+                case MUXER_TS:  encoding->setContainer("Mpeg TS");break;
+                case MUXER_VCD: encoding->setContainer("Mpeg VCD");break;
+                case MUXER_SVCD:encoding->setContainer("Mpeg SVCD");break;
+                case MUXER_DVD: encoding->setContainer("Mpeg DVD");break;
+                default:
+                    ADM_assert(0);           
+            }
+            
 	}
+        else
+            encoding->setContainer("Mpeg ES");
 	for(uint32_t i=0;i<_total;i++)
 			{
             			if(!incoming->getFrameNumberNoAlloc(i, &size,
@@ -722,6 +744,25 @@ int intra,q;
 	return 1;
 }
 /*--------------------------------------------------------------------*/
+uint32_t		quantstat[] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+void print_quant_stat(const char *n){
+  char *str = (char*)ADM_alloc( strlen(n) + 4 );
+  unsigned int i=2,sum=0,total=0;
+  FILE *fd;
+   ADM_assert( str );
+   strcpy(str,n);
+   strcat(str,".qs");
+   if( (fd=fopen(str,"wb")) ){
+      for(;i<32;i++){
+         fprintf(fd,"Quant % 2u: % 7u times\n",i,quantstat[i]);
+         sum+=i*quantstat[i];
+         total+=quantstat[i];
+      }
+      fprintf(fd,"\nQuant over all: %2.2f\n",(float)sum/(float)total);
+      fclose(fd);
+   }
+   ADM_dealloc( str );
+}
 uint8_t  mpegWritter::dopass2(char *name,char *statname,uint32_t final_size,uint32_t bitrate,
 				ADM_MPEGTYPE mpegtype,int matrix,uint8_t interlaced,
 					uint8_t bff,        // WLA
@@ -735,10 +776,6 @@ FILE			*fd=NULL;
 uint64_t		total_size=0;
 uint32_t		len,flags,type,outquant,audiolen;
 
-uint32_t		quantstat[] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
-
-	#define PRINT_QUANT_STAT {unsigned int i=2,sum=0,total=0;for(;i<32;i++){printf("Quant % 2u: % 7u times\n",i,quantstat[i]);sum+=i*quantstat[i];total+=quantstat[i];}printf("\nQuant over all: %2.2f\n",(float)sum/(float)total);}
-
    	incoming = getLastVideoFilter (frameStart,frameEnd-frameStart);
 	if(!_audio)
 	{
@@ -876,7 +913,7 @@ uint32_t		quantstat[] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
 				
 		if(!encoding->isAlive())
 		{
-			 PRINT_QUANT_STAT
+			 print_quant_stat(name);
 			 end();
 			 fclose(fd);
 			 return 0;
@@ -935,7 +972,7 @@ uint32_t		quantstat[] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
 		_muxer=NULL;	
 	}
 
-	PRINT_QUANT_STAT
+	print_quant_stat(name);
 	 end();
 	return 1;
 }
@@ -1019,8 +1056,12 @@ uint32_t fps1000;
 	_audioBuffer=new uint8_t[MAXAUDIO]; // equivalent to 1 sec @ 448 kbps, should be more than
 					// enough, even with the buffering
 	printf("----- Audio Track for mpeg Ready.------\n");
-	
-	_muxer=new lavMuxer();	
+
+        if(type!=MUXER_TS)
+	       _muxer=new mplexMuxer();	
+        else
+               _muxer=new tsMuxer(); //lavMuxer();
+        
 	// open( char *filename, uint32_t vbitrate, aviInfo *info, WAVHeader *audioheader,float need);
 	aviInfo info;
 	info.width=getLastVideoFilter()->getInfo()->width;
