@@ -75,10 +75,12 @@ WAVHeader	*info=NULL;
 		{
 			audioStream=new ogm_page(_fd,2);
 		}
+/*
 		else 
 		{			
 			return 0;
 		}
+*/
 		//
 		if(audioProcessMode)
 		{
@@ -87,6 +89,7 @@ WAVHeader	*info=NULL;
 			audioFilter=  buildAudioFilter (currentaudiostream,
 					video_body->getTime (frameStart),
 					0xffffffff);
+                        if(!audioFilter) return 0;
 			fcc=audioFilter->getInfo()->encoding;
 			encoding_gui->setAudioCodec(getStrFromAudioCodec(fcc));
 		}
