@@ -78,14 +78,17 @@ static opt_def opt_defs [] = {
 	{"test.long",		LONG,	"1",	NULL,	"-4",	"999999999999"},
 	{"test.ulong",		ULONG,	"2",	NULL,	"0",	"999999999999"},
 	{"test.float",	FLOAT,	"0.0",	NULL,	"-0.35","0.35"	},
-	{"settings.mpegsplit",	UINT,	"790",	NULL,	"400",	"900"	},
+	{"settings.mpegsplit",	UINT,	"790",	NULL,	"400",	"5000"	},
 	{"codecs.preferredcodec",		STRING,"FFmpeg4",NULL, NULL, NULL },
 	{"device.audiodevice",	STRING,"OSS",	NULL, NULL, NULL },
+	{"device.audio.alsa_device",		STRING,"plughw:0,0",NULL, NULL, NULL },
+	{"device.videodevice",		UINT,	"0",	NULL,	"0",	"10"	},
 	{"lastfiles.file1",		STRING,"",	NULL, NULL, NULL },
 	{"lastfiles.file2",		STRING,"",	NULL, NULL, NULL },
 	{"lastfiles.file3",		STRING,"",	NULL, NULL, NULL },
 	{"lastfiles.file4",		STRING,"",	NULL, NULL, NULL },
-	{"lastdir",		STRING,"",	NULL, NULL, NULL },
+	{"lastdir_read",		STRING,"",	NULL, NULL, NULL },
+	{"lastdir_write",		STRING,"",	NULL, NULL, NULL },
 	{"lame_cli",		STRING,"",	NULL, NULL, NULL },
 	{"pipe_cmd",		STRING,"",	NULL, NULL, NULL },
 	{"pipe_param",		STRING,"",	NULL, NULL, NULL },
@@ -99,10 +102,11 @@ static opt_def opt_defs [] = {
 	{"feature.ignoresavedmarkers",		UINT,	"0",	NULL,	"0",	"1"	},
 	{"feature.use_lavcodec_mpeg",		UINT,	"0",	NULL,	"0",	"1"	},
 	{"feature.disable_nuv_resync",		UINT,	"0",	NULL,	"0",	"1"	},
-	{"feature.tryautoidx",		UINT,	"0",	NULL,	"0",	"1"	}
+	{"feature.tryautoidx",		UINT,	"0",	NULL,	"0",	"1"	},
+	{"feature.use_odml",		UINT,	"0",	NULL,	"0",	"1"	}
 };
 
-int num_opts = 60;
+int num_opts = 64;
 // </prefs_gen>
 
 #ifdef USE_LIBXML2
