@@ -49,11 +49,14 @@ typedef enum {
 	SETTINGS_MPEGSPLIT,
 	CODECS_PREFERREDCODEC,
 	DEVICE_AUDIODEVICE,
+	DEVICE_AUDIO_ALSA_DEVICE,
+	DEVICE_VIDEODEVICE,
 	LASTFILES_FILE1,
 	LASTFILES_FILE2,
 	LASTFILES_FILE3,
 	LASTFILES_FILE4,
-	LASTDIR,
+	LASTDIR_READ,
+	LASTDIR_WRITE,
 	LAME_CLI,
 	PIPE_CMD,
 	PIPE_PARAM,
@@ -67,7 +70,8 @@ typedef enum {
 	FEATURE_IGNORESAVEDMARKERS,
 	FEATURE_USE_LAVCODEC_MPEG,
 	FEATURE_DISABLE_NUV_RESYNC,
-	FEATURE_TRYAUTOIDX
+	FEATURE_TRYAUTOIDX,
+	FEATURE_USE_ODML
 } options;
 // </prefs_gen>
 
